#!/usr/bin/python
#
# Copyright (C) 2006 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = 'api.rboyd@google.com (Ryan Boyd)'

import unittest
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import atom
import atom.mock_http
import gdata.calendar
import gdata.calendar.service
import random
import getpass


username = ''
password = ''


class CalendarServiceUnitTest(unittest.TestCase):
  
  def setUp(self):
    self.cal_client = gdata.calendar.service.CalendarService()
    self.cal_client.email = username 
    self.cal_client.password = password
    self.cal_client.source = 'GCalendarClient "Unit" Tests'

  def tearDown(self):
    # No teardown needed
    pass

  def testUrlScrubbing(self):
    self.assertEquals(self.cal_client._RemoveStandardUrlPrefix(
        '/test'), '/test')
    self.assertEquals(self.cal_client._RemoveStandardUrlPrefix(
        'http://www.google.com/calendar/test'), '/calendar/test')
    self.assertEquals(self.cal_client._RemoveStandardUrlPrefix(
        'https://www.google.com/calendar/test'),
        'https://www.google.com/calendar/test')

  def testPostUpdateAndDeleteSubscription(self):
    """Test posting a new subscription, updating it, deleting it"""
    self.cal_client.ProgrammaticLogin()

    subscription_id = 'c4o4i7m2lbamc4k26sc2vokh5g%40group.calendar.google.com'
    subscription_url = '%s%s' % (
        'http://www.google.com/calendar/feeds/default/allcalendars/full/', 
        subscription_id)

    # Subscribe to Google Doodles calendar        
    calendar = gdata.calendar.CalendarListEntry()
    calendar.id = atom.Id(text=subscription_id)
    returned_calendar = self.cal_client.InsertCalendarSubscription(calendar)
    self.assertEquals(subscription_url, returned_calendar.id.text)
    self.assertEquals('Google Doodles', returned_calendar.title.text)

    # Update subscription
    calendar_to_update = self.cal_client.GetCalendarListEntry(subscription_url)
    self.assertEquals('Google Doodles', calendar_to_update.title.text) 
    self.assertEquals('true', calendar_to_update.selected.value) 
    calendar_to_update.selected.value = 'false'
    self.assertEquals('false', calendar_to_update.selected.value) 
    updated_calendar = self.cal_client.UpdateCalendar(calendar_to_update)
    self.assertEquals('false', updated_calendar.selected.value) 
    
    # Delete subscription
    response = self.cal_client.DeleteCalendarEntry(
        returned_calendar.GetEditLink().href)
    self.assertEquals(True, response)

  def testPostUpdateAndDeleteCalendar(self):
    """Test posting a new calendar, updating it, deleting it"""
    self.cal_client.ProgrammaticLogin()

    # New calendar to create
    title='Little League Schedule'
    description='This calendar contains practice and game times'
    time_zone='America/Los_Angeles'
    hidden=False
    location='Oakland'
    color='#2952A3'

    # Calendar object
    calendar = gdata.calendar.CalendarListEntry()
    calendar.title = atom.Title(text=title)
    calendar.summary = atom.Summary(text=description)
    calendar.where = gdata.calendar.Where(value_string=location)
    calendar.color = gdata.calendar.Color(value=color)
    calendar.timezone = gdata.calendar.Timezone(value=time_zone)
    if hidden:
      calendar.hidden = gdata.calendar.Hidden(value='true')
    else:
      calendar.hidden = gdata.calendar.Hidden(value='false')

    # Create calendar
    new_calendar = self.cal_client.InsertCalendar(new_calendar=calendar)
    self.assertEquals(title, new_calendar.title.text)
    self.assertEquals(description, new_calendar.summary.text)
    self.assertEquals(location, new_calendar.where.value_string)
    self.assertEquals(color, new_calendar.color.value)
    self.assertEquals(time_zone, new_calendar.timezone.value)
    if hidden:
      self.assertEquals('true', new_calendar.hidden.value) 
    else:
      self.assertEquals('false', new_calendar.hidden.value) 

    # Update calendar
    calendar_to_update = self.cal_client.GetCalendarListEntry(
        new_calendar.id.text)
    updated_title = 'This is the updated title'
    calendar_to_update.title.text = updated_title 
    updated_calendar = self.cal_client.UpdateCalendar(calendar_to_update)
    self.assertEquals(updated_title, updated_calendar.title.text)
   
    # Delete calendar
    calendar_to_delete  = self.cal_client.GetCalendarListEntry(
        new_calendar.id.text)
    self.cal_client.Delete(calendar_to_delete.GetEditLink().href) 

    return new_calendar
    
  def testPostAndDeleteExtendedPropertyEvent(self):
    """Test posting a new entry with an extended property, deleting it"""
    # Get random data for creating event
    r = random.Random()
    r.seed()
    random_event_number = str(r.randint(100000,1000000))
    random_event_title = 'My Random Extended Property Test Event %s' % ( 
        random_event_number)

    # Set event data 
    event = gdata.calendar.CalendarEventEntry()
    event.author.append(atom.Author(name=atom.Name(text='GData Test user')))
    event.title = atom.Title(text=random_event_title)
    event.content = atom.Content(text='Picnic with some lunch')
    event.extended_property.append(gdata.calendar.ExtendedProperty(
        name='prop test name', value='prop test value'))

    # Insert event 
    self.cal_client.ProgrammaticLogin()
    new_event = self.cal_client.InsertEvent(event, 
        '/calendar/feeds/default/private/full')

    self.assertEquals(event.extended_property[0].value,
        new_event.extended_property[0].value)

    # Delete the event
    self.cal_client.DeleteEvent(new_event.GetEditLink().href)

  # WARNING: Due to server-side issues, this test takes a while (~60seconds)
  def testPostEntryWithCommentAndDelete(self):
    """Test posting a new entry with an extended property, deleting it"""
    # Get random data for creating event
    r = random.Random()
    r.seed()
    random_event_number = str(r.randint(100000,1000000))
    random_event_title = 'My Random Comments Test Event %s' % (
        random_event_number)

    # Set event data
    event = gdata.calendar.CalendarEventEntry()
    event.author.append(atom.Author(name=atom.Name(text='GData Test user')))
    event.title = atom.Title(text=random_event_title)
    event.content = atom.Content(text='Picnic with some lunch')

    # Insert event
    self.cal_client.ProgrammaticLogin()
    new_event = self.cal_client.InsertEvent(event,
        '/calendar/feeds/default/private/full')

    # Get comments feed
    comments_url = new_event.comments.feed_link.href
    comments_query = gdata.calendar.service.CalendarEventCommentQuery(comments_url)
    comments_feed = self.cal_client.CalendarQuery(comments_query)

    # Add comment
    comments_entry = gdata.calendar.CalendarEventCommentEntry()
    comments_entry.content = atom.Content(text='Comments content')
    comments_entry.author.append(
        atom.Author(name=atom.Name(text='GData Test user'),
            email=atom.Email(text=username)))
    new_comments_entry = self.cal_client.InsertEventComment(comments_entry,
        comments_feed.GetPostLink().href)
  
    # Delete the event
    event_to_delete = self.cal_client.GetCalendarEventEntry(new_event.id.text)
    self.cal_client.DeleteEvent(event_to_delete.GetEditLink().href)

  def testPostQueryUpdateAndDeleteEvents(self):
    """Test posting a new entry, updating it, deleting it, querying for it"""

    # Get random data for creating event
    r = random.Random()
    r.seed()
    random_event_number = str(r.randint(100000,1000000))
    random_event_title = 'My Random Test Event %s' % random_event_number
        
    random_start_hour = (r.randint(1,1000000) % 23)
    random_end_hour = random_start_hour + 1
    non_random_start_minute = 0
    non_random_end_minute = 0
    random_month = (r.randint(1,1000000) % 12 + 1)
    random_day_of_month = (r.randint(1,1000000) % 28 + 1)
    non_random_year = 2008
    start_time = '%04d-%02d-%02dT%02d:%02d:00.000-05:00' % (
        non_random_year, random_month, random_day_of_month,
        random_start_hour, non_random_start_minute,)
    end_time = '%04d-%02d-%02dT%02d:%02d:00.000-05:00' % (
        non_random_year, random_month, random_day_of_month,
        random_end_hour, non_random_end_minute,)

    # Set event data 
    event = gdata.calendar.CalendarEventEntry()
    event.author.append(atom.Author(name=atom.Name(text='GData Test user')))
    event.title = atom.Title(text=random_event_title)
    event.content = atom.Content(text='Picnic with some lunch')
    event.where.append(gdata.calendar.Where(value_string='Down by the river'))
    event.when.append(gdata.calendar.When(start_time=start_time,end_time=end_time))

    # Insert event 
    self.cal_client.ProgrammaticLogin()
    new_event = self.cal_client.InsertEvent(event, 
        '/calendar/feeds/default/private/full')

    # Ensure that atom data returned from calendar server equals atom data sent 
    self.assertEquals(event.title.text, new_event.title.text)
    self.assertEquals(event.content.text, new_event.content.text)

    # Ensure that gd:where data returned from calendar equals value sent
    self.assertEquals(event.where[0].value_string,
        new_event.where[0].value_string)

    # Commented out as dateutil is not in this repository
    # Ensure that dates returned from calendar server equals dates sent 
    #start_time_py = parse(event.when[0].start_time)
    #start_time_py_new = parse(new_event.when[0].start_time)
    #self.assertEquals(start_time_py, start_time_py_new)

    #end_time_py = parse(event.when[0].end_time)
    #end_time_py_new = parse(new_event.when[0].end_time)
    #self.assertEquals(end_time_py, end_time_py_new)

    # Update event
    event_to_update = new_event
    updated_title_text = event_to_update.title.text + ' - UPDATED'
    event_to_update.title = atom.Title(text=updated_title_text)

    updated_event = self.cal_client.UpdateEvent(
        event_to_update.GetEditLink().href, event_to_update)

    # Ensure that updated title was set in the updated event
    self.assertEquals(event_to_update.title.text, updated_event.title.text)

    # Delete the event
    self.cal_client.DeleteEvent(updated_event.GetEditLink().href)

    # Ensure deleted event is marked as canceled in the feed
    after_delete_query = gdata.calendar.service.CalendarEventQuery()
    after_delete_query.updated_min = '2007-01-01'
    after_delete_query.text_query = str(random_event_number) 
    after_delete_query.max_results = '1'
    after_delete_query_result = self.cal_client.CalendarQuery(
        after_delete_query)

    # Ensure feed returned at max after_delete_query.max_results events 
    self.assert_(
        len(after_delete_query_result.entry) <= after_delete_query.max_results)

    # Ensure status of returned event is canceled
    self.assertEquals(after_delete_query_result.entry[0].event_status.value,
        'CANCELED')

  def testEventWithSyncEventAndUID(self):
    """Test posting a new entry (with syncEvent and a UID) and deleting it."""

    # Get random data for creating event
    r = random.Random()
    r.seed()
    random_event_number = str(r.randint(100000,1000000))
    random_event_title = 'My Random Test Event %s' % random_event_number

    random_start_hour = (r.randint(1,1000000) % 23)
    random_end_hour = random_start_hour + 1
    non_random_start_minute = 0
    non_random_end_minute = 0
    random_month = (r.randint(1,1000000) % 12 + 1)
    random_day_of_month = (r.randint(1,1000000) % 28 + 1)
    non_random_year = 2008
    start_time = '%04d-%02d-%02dT%02d:%02d:00.000-05:00' % (
        non_random_year, random_month, random_day_of_month,
        random_start_hour, non_random_start_minute,)
    end_time = '%04d-%02d-%02dT%02d:%02d:00.000-05:00' % (
        non_random_year, random_month, random_day_of_month,
        random_end_hour, non_random_end_minute,)

    # create a random event ID. I'm mimicing an example from outlook here,
    # the format doesn't seem to be important per the RFC except for being
    # globally unique.
    uid_string = ''
    for i in xrange(121):
      uid_string += "%X" % r.randint(0, 0xf)

    # Set event data
    event = gdata.calendar.CalendarEventEntry()
    event.author.append(atom.Author(name=atom.Name(text='GData Test user')))
    event.title = atom.Title(text=random_event_title)
    event.content = atom.Content(text='Picnic with some lunch')
    event.where.append(gdata.calendar.Where(value_string='Down by the river'))
    event.when.append(gdata.calendar.When(
        start_time=start_time,end_time=end_time))
    event.sync_event = gdata.calendar.SyncEvent('true')
    event.uid = gdata.calendar.UID(value=uid_string)

    # Insert event
    self.cal_client.ProgrammaticLogin()
    new_event = self.cal_client.InsertEvent(event,
        '/calendar/feeds/default/private/full')

    # Inserting it a second time should fail, as it'll have the same UID
    try:
      bad_event = self.cal_client.InsertEvent(event,
          '/calendar/feeds/default/private/full')
      self.fail('Was able to insert an event with a duplicate UID')
    except gdata.service.RequestError, error:
      # for the current problem with redirects, just re-raise so the
      # failure doesn't seem to be because of the duplicate UIDs.
      status = error[0]['status']
      if status == 302:
        raise

      # otherwise, make sure it was the right error
      self.assertEquals(error[0]['status'], 409)
      self.assertEquals(error[0]['reason'], 'Conflict')

    # Ensure that atom data returned from calendar server equals atom data
    # sent
    self.assertEquals(event.title.text, new_event.title.text)
    self.assertEquals(event.content.text, new_event.content.text)

    # Ensure that gd:where data returned from calendar equals value sent
    self.assertEquals(event.where[0].value_string,
        new_event.where[0].value_string)

    # Delete the event
    self.cal_client.DeleteEvent(new_event.GetEditLink().href)
 

  def testCreateAndDeleteEventUsingBatch(self):
    # Get random data for creating event
    r = random.Random()
    r.seed()
    random_event_number = str(r.randint(100000,1000000))
    random_event_title = 'My Random Comments Test Event %s' % (
        random_event_number)

    # Set event data
    event = gdata.calendar.CalendarEventEntry()
    event.author.append(atom.Author(name=atom.Name(text='GData Test user')))
    event.title = atom.Title(text=random_event_title)
    event.content = atom.Content(text='Picnic with some lunch')

    # Form a batch request
    batch_request = gdata.calendar.CalendarEventFeed()
    batch_request.AddInsert(entry=event)

    # Execute the batch request to insert the event.
    self.cal_client.ProgrammaticLogin()
    batch_result = self.cal_client.ExecuteBatch(batch_request, 
        gdata.calendar.service.DEFAULT_BATCH_URL)

    self.assertEquals(len(batch_result.entry), 1)
    self.assertEquals(batch_result.entry[0].title.text, random_event_title)
    self.assertEquals(batch_result.entry[0].batch_operation.type, 
                      gdata.BATCH_INSERT)
    self.assertEquals(batch_result.GetBatchLink().href, 
                      gdata.calendar.service.DEFAULT_BATCH_URL)

    # Create a batch request to delete the newly created entry.
    batch_delete_request = gdata.calendar.CalendarEventFeed()
    batch_delete_request.AddDelete(entry=batch_result.entry[0])
  
    batch_delete_result = self.cal_client.ExecuteBatch(batch_delete_request, 
        batch_result.GetBatchLink().href)
    self.assertEquals(len(batch_delete_result.entry), 1)
    self.assertEquals(batch_delete_result.entry[0].batch_operation.type, 
                      gdata.BATCH_DELETE)

  def testCorrectReturnTypesForGetMethods(self):
    self.cal_client.ProgrammaticLogin()

    result = self.cal_client.GetCalendarEventFeed()
    self.assertEquals(isinstance(result, gdata.calendar.CalendarEventFeed), 
                      True)

  def testValidHostName(self):
    mock_http = atom.mock_http.MockHttpClient()
    response = atom.mock_http.MockResponse(body='<entry/>', status=200,
        reason='OK')
    mock_http.add_response(response, 'GET',
        'https://www.google.com/calendar/feeds/default/allcalendars/full')
    self.cal_client.ssl = True
    self.cal_client.http_client = mock_http
    self.cal_client.SetAuthSubToken('foo')
    self.assertEquals(str(self.cal_client.token_store.find_token(
        'https://www.google.com/calendar/feeds/default/allcalendars/full')),
        'AuthSub token=foo')
    resp = self.cal_client.Get('/calendar/feeds/default/allcalendars/full')
    self.assert_(resp is not None)


class CalendarEventQueryUnitTest(unittest.TestCase):

  def setUp(self):
    self.query = gdata.calendar.service.CalendarEventQuery()

  def testOrderByValidatesValues(self):
    self.query.orderby = 'lastmodified'
    self.assertEquals(self.query.orderby, 'lastmodified')
    try:
      self.query.orderby = 'illegal input'
      self.fail()
    except gdata.calendar.service.Error:
      self.assertEquals(self.query.orderby, 'lastmodified')
      
  def testSortOrderValidatesValues(self):
    self.query.sortorder = 'a'
    self.assertEquals(self.query.sortorder, 'a')
    try:
      self.query.sortorder = 'illegal input'
      self.fail()
    except gdata.calendar.service.Error:
      self.assertEquals(self.query.sortorder, 'a')

  def testTimezoneParameter(self):
    self.query.ctz = 'America/Los_Angeles'
    self.assertEquals(self.query['ctz'], 'America/Los_Angeles')
    self.assert_(self.query.ToUri().find('America%2FLos_Angeles') > -1)


if __name__ == '__main__':
  print ('Google Calendar Test\nNOTE: Please run these tests only with a '
         'test account. The tests may delete or update your data.')
  username = raw_input('Please enter your username: ')
  password = getpass.getpass()
  unittest.main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This module is used for version 2 of the Google Data APIs.
# These tests attempt to connect to Google servers.


__author__ = 'Vic Fryzel <vf@google.com>'


import unittest
import gdata.client
import gdata.data
import gdata.gauth
import gdata.calendar_resource.client
import gdata.calendar_resource.data
import gdata.test_config as conf


conf.options.register_option(conf.APPS_DOMAIN_OPTION)


class CalendarResourceClientTest(unittest.TestCase):

  def setUp(self):
    self.client = gdata.calendar_resource.client.CalendarResourceClient(
        domain='example.com')
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.calendar_resource.client.CalendarResourceClient(
          domain=conf.options.get_value('appsdomain'))
      if conf.options.get_value('ssl') == 'true':
        self.client.ssl = True
      conf.configure_client(self.client, 'CalendarResourceClientTest',
          self.client.auth_service, True)

  def tearDown(self):
    conf.close_client(self.client)

  def testClientConfiguration(self):
    self.assertEqual('apps-apis.google.com', self.client.host)
    self.assertEqual('2.0', self.client.api_version)
    self.assertEqual('apps', self.client.auth_service)
    self.assertEqual(gdata.gauth.AUTH_SCOPES['apps'], self.client.auth_scopes)
    if conf.options.get_value('runlive') == 'true':
      self.assertEqual(self.client.domain, conf.options.get_value('appsdomain'))
    else:
      self.assertEqual(self.client.domain, 'example.com')

  def testMakeResourceFeedUri(self):
    self.assertEqual('/a/feeds/calendar/resource/2.0/%s/' % self.client.domain,
        self.client.MakeResourceFeedUri())
    self.assertEqual('/a/feeds/calendar/resource/2.0/%s/CR-NYC-14-12-BR'
        % self.client.domain,
        self.client.MakeResourceFeedUri(resource_id='CR-NYC-14-12-BR'))
    self.assertEqual('/a/feeds/calendar/resource/2.0/%s/?test=1'
        % self.client.domain,
        self.client.MakeResourceFeedUri(params={'test': 1}))
    self.assertEqual('/a/feeds/calendar/resource/2.0/%s/CR-NYC-14-12-BR?test=1'
        % self.client.domain,
        self.client.MakeResourceFeedUri(resource_id='CR-NYC-14-12-BR',
            params={'test': 1}))

  def testCreateRetrieveUpdateDelete(self):
    if not conf.options.get_value('runlive') == 'true':
      return

    # Either load the recording or prepare to make a live request.
    conf.configure_cache(self.client, 'testCreateUpdateDelete')

    try:
      new_entry = self.client.CreateResource(
          'CR-NYC-14-12-BR', 'Boardroom',
          ('This conference room is in New York City, building 14, floor 12, '
           'Boardroom'), 'CR')
    except Exception, e:
      print e
      self.client.delete_resource('CR-NYC-14-12-BR')
      # If the test failed to run to completion
      # the resource may already exist
      new_entry = self.client.CreateResource(
          'CR-NYC-14-12-BR', 'Boardroom',
          ('This conference room is in New York City, building 14, floor 12, '
           'Boardroom'), 'CR')

    self.assert_(isinstance(new_entry,
        gdata.calendar_resource.data.CalendarResourceEntry))
    self.assertEqual(new_entry.resource_id, 'CR-NYC-14-12-BR')
    self.assertEqual(new_entry.resource_common_name, 'Boardroom')
    self.assertEqual(new_entry.resource_description,
        ('This conference room is in New York City, building 14, floor 12, '
         'Boardroom'))
    self.assertEqual(new_entry.resource_type, 'CR')

    fetched_entry = self.client.get_resource(resource_id='CR-NYC-14-12-BR')
    self.assert_(isinstance(fetched_entry,
        gdata.calendar_resource.data.CalendarResourceEntry))
    self.assertEqual(fetched_entry.resource_id, 'CR-NYC-14-12-BR')
    self.assertEqual(fetched_entry.resource_common_name, 'Boardroom')
    self.assertEqual(fetched_entry.resource_description,
        ('This conference room is in New York City, building 14, floor 12, '
         'Boardroom'))
    self.assertEqual(fetched_entry.resource_type, 'CR')

    new_entry.resource_id = 'CR-MTV-14-12-BR'
    new_entry.resource_common_name = 'Executive Boardroom'
    new_entry.resource_description = 'This conference room is in Mountain View'
    new_entry.resource_type = 'BR'
    updated_entry = self.client.update(new_entry)
    self.assert_(isinstance(updated_entry,
        gdata.calendar_resource.data.CalendarResourceEntry))
    self.assertEqual(updated_entry.resource_id, 'CR-MTV-14-12-BR')
    self.assertEqual(updated_entry.resource_common_name, 'Executive Boardroom')
    self.assertEqual(updated_entry.resource_description,
        'This conference room is in Mountain View')
    self.assertEqual(updated_entry.resource_type, 'BR')

    self.client.delete_resource('CR-NYC-14-12-BR')


def suite():
  return conf.build_suite([CalendarResourceClientTest])


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This file demonstrates how to use the Google Data API's Python client library
# to interface with the Blogger service.  There are examples for the following
# operations:
#
# * Retrieving the list of all the user's blogs
# * Retrieving all posts on a single blog
# * Performing a date-range query for posts on a blog
# * Creating draft posts and publishing posts
# * Updating posts
# * Retrieving comments
# * Creating comments
# * Deleting comments
# * Deleting posts


__author__ = 'lkeppler@google.com (Luke Keppler)'


import gdata.blogger.client
import gdata.client
import gdata.sample_util
import gdata.data
import atom.data


class BloggerExample:

  def __init__(self):
    """Creates a GDataService and provides ClientLogin auth details to it.
    The email and password are required arguments for ClientLogin.  The
    'source' defined below is an arbitrary string, but should be used to
    reference your name or the name of your organization, the app name and
    version, with '-' between each of the three values."""

    # Authenticate using ClientLogin, AuthSub, or OAuth.
    self.client = gdata.blogger.client.BloggerClient()
    gdata.sample_util.authorize_client(
        self.client, service='blogger', source='Blogger_Python_Sample-2.0',
        scopes=['http://www.blogger.com/feeds/'])

    # Get the blog ID for the first blog.
    feed = self.client.get_blogs()
    self.blog_id = feed.entry[0].get_blog_id()

  def PrintUserBlogTitles(self):
    """Prints a list of all the user's blogs."""

    # Request the feed.
    feed = self.client.get_blogs()

    # Print the results.
    print feed.title.text
    for entry in feed.entry:
      print "\t" + entry.title.text
    print

  def CreatePost(self, title, content, is_draft):
    """This method creates a new post on a blog.  The new post can be stored as
    a draft or published based on the value of the is_draft parameter.  The
    method creates an GDataEntry for the new post using the title, content,
    author_name and is_draft parameters.  With is_draft, True saves the post as
    a draft, while False publishes the post.  Then it uses the given
    GDataService to insert the new post.  If the insertion is successful, the
    added post (GDataEntry) will be returned.
    """
    return self.client.add_post(self.blog_id, title, content, draft=is_draft)

  def PrintAllPosts(self):
    """This method displays the titles of all the posts in a blog.  First it
    requests the posts feed for the blogs and then it prints the results.
    """

    # Request the feed.
    feed = self.client.get_posts(self.blog_id)

    # Print the results.
    print feed.title.text
    for entry in feed.entry:
      if not entry.title.text:
        print "\tNo Title"
      else:
        print "\t" + entry.title.text.encode('utf-8')
    print

  def PrintPostsInDateRange(self, start_time, end_time):
    """This method displays the title and modification time for any posts that
    have been created or updated in the period between the start_time and
    end_time parameters.  The method creates the query, submits it to the
    GDataService, and then displays the results.
  
    Note that while the start_time is inclusive, the end_time is exclusive, so
    specifying an end_time of '2007-07-01' will include those posts up until
    2007-6-30 11:59:59PM.

    The start_time specifies the beginning of the search period (inclusive),
    while end_time specifies the end of the search period (exclusive).
    """

    # Create query and submit a request.
    query = gdata.blogger.client.Query(updated_min=start_time,
                                       updated_max=end_time,
                                       order_by='updated')
    print query.updated_min
    print query.order_by
    feed = self.client.get_posts(self.blog_id, query=query)

    # Print the results.
    print feed.title.text + " posts between " + start_time + " and " + end_time
    print feed.title.text
    for entry in feed.entry:
      if not entry.title.text:
        print "\tNo Title"
      else:
        print "\t" + entry.title.text
    print

  def UpdatePostTitle(self, entry_to_update, new_title):
    """This method updates the title of the given post.  The GDataEntry object
    is updated with the new title, then a request is sent to the GDataService.
    If the insertion is successful, the updated post will be returned.

    Note that other characteristics of the post can also be modified by
    updating the values of the entry object before submitting the request.

    The entry_to_update is a GDatEntry containing the post to update.
    The new_title is the text to use for the post's new title.  Returns: a
    GDataEntry containing the newly-updated post.
    """
    
    # Set the new title in the Entry object
    entry_to_update.title = atom.data.Title(type='xhtml', text=new_title)
    return self.client.update(entry_to_update)

  def CreateComment(self, post_id, comment_text):
    """This method adds a comment to the specified post.  First the comment
    feed's URI is built using the given post ID.  Then a GDataEntry is created
    for the comment and submitted to the GDataService.  The post_id is the ID
    of the post on which to post comments.  The comment_text is the text of the
    comment to store.  Returns: an entry containing the newly-created comment

    NOTE: This functionality is not officially supported yet.
    """
    return self.client.add_comment(self.blog_id, post_id, comment_text)

  def PrintAllComments(self, post_id):
    """This method displays all the comments for the given post.  First the
    comment feed's URI is built using the given post ID.  Then the method
    requests the comments feed and displays the results.  Takes the post_id
    of the post on which to view comments. 
    """

    feed = self.client.get_post_comments(self.blog_id, post_id)

    # Display the results
    print feed.title.text
    for entry in feed.entry:
      print "\t" + entry.title.text
      print "\t" + entry.updated.text
    print

  def DeleteComment(self, comment_entry):
    """This method removes the comment specified by the given edit_link_href, the
    URI for editing the comment.
    """
    self.client.delete(comment_entry)

  def DeletePost(self, post_entry):
    """This method removes the post specified by the given edit_link_href, the
    URI for editing the post.
    """

    self.client.delete(post_entry)
  
  def run(self):
    """Runs each of the example methods defined above, demonstrating how to
    interface with the Blogger service.
    """

    # Demonstrate retrieving a list of the user's blogs.
    self.PrintUserBlogTitles()
  
    # Demonstrate how to create a draft post.
    draft_post = self.CreatePost('Snorkling in Aruba',
      '<p>We had <b>so</b> much fun snorkling in Aruba<p>',
      True)
    print 'Successfully created draft post: "' + draft_post.title.text + '".\n'

    # Delete the draft blog post.
    self.client.delete(draft_post)
  
    # Demonstrate how to publish a public post.
    public_post = self.CreatePost("Back from vacation",
      "<p>I didn't want to leave Aruba, but I ran out of money :(<p>",
      False)
    print "Successfully created public post: \"" + public_post.title.text + "\".\n"
  
    # Demonstrate various feed queries.
    print "Now listing all posts."
    self.PrintAllPosts()
    print "Now listing all posts between 2007-04-04 and 2007-04-23."
    self.PrintPostsInDateRange("2007-04-04", "2007-04-23")

    # Demonstrate updating a post's title.
    print "Now updating the title of the post we just created:"
    public_post = self.UpdatePostTitle(public_post, "The party's over")
    print "Successfully changed the post's title to \"" + public_post.title.text + "\".\n"
  
    # Demonstrate how to retrieve the comments for a post.

    # Get the post ID and build the comments feed URI for the specified post
    post_id = public_post.get_post_id()
    
    print "Now posting a comment on the post titled: \"" + public_post.title.text + "\"."
    comment = self.CreateComment(post_id, "Did you see any sharks?")
    print "Successfully posted \"" + comment.content.text + "\" on the post titled: \"" + public_post.title.text + "\".\n"
    
    comment_id = comment.GetCommentId()
    
    print "Now printing all comments"
    self.PrintAllComments(post_id)
   
    # Delete the comment we just posted
    print "Now deleting the comment we just posted"
    self.DeleteComment(comment)
    print "Successfully deleted comment." 
    self.PrintAllComments(post_id)

    # Demonstrate deleting posts.
    print "Now deleting the post titled: \"" + public_post.title.text + "\"."
    self.DeletePost(public_post)
    print "Successfully deleted post." 
    self.PrintAllPosts()


def main():
  """The main function runs the BloggerExample application.
  
  NOTE:  It is recommended that you run this sample using a test account.
  """
  sample = BloggerExample()
  sample.run()


if __name__ == '__main__':
  main()



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Demonstrates Email Settings API's POP settings.
   Enables POP for all of the domain's users for all messages and
   archives Gmail's copy.
"""

__author__ = 'Gunjan Sharma <gunjansharma@google.com>'

import getopt
import sys
import gdata.apps.client
import gdata.apps.emailsettings.client


SCOPES = ['https://apps-apis.google.com/a/feeds/emailsettings/2.0/',
          'https://apps-apis.google.com/a/feeds/user/']


class PopSettingsException(Exception):
  """Exception class for PopSettings to show appropriate error message."""

  def __init__(self, message):
    """Create a new PopSettingsException with the appropriate error message."""
    super(PopSettingsException, self).__init__(message)


class PopSettings(object):
  """Sample demonstrating how to enable POP for all of a domain's users."""

  def __init__(self, consumer_key, consumer_secret, domain):
    """Create a new PopSettings object configured for a domain.

    Args:
      consumer_key: [string] The consumerKey of the domain.
      consumer_secret: [string] The consumerSecret of the domain.
      domain: [string] The domain whose user's POP settings to be changed.
    """
    self.consumer_key = consumer_key
    self.consumer_secret = consumer_secret
    self.domain = domain

  def Authorize(self):
    """Asks the domain's admin to authorize.

       Access to two APIs needs to be authorized,
       provisioning users and Gmail settings.
       The function creates clients for both APIs.
    """
    self.email_settings_client = (
        gdata.apps.emailsettings.client.EmailSettingsClient(
            domain=self.domain))
    self.provisioning_client = gdata.apps.client.AppsClient(domain=self.domain)
    request_token = self.email_settings_client.GetOAuthToken(
        SCOPES, None, self.consumer_key, consumer_secret=self.consumer_secret)
    print request_token.GenerateAuthorizationUrl()
    raw_input('Manually go to the above URL and authenticate.'
              'Press Return after authorization.')
    access_token = self.email_settings_client.GetAccessToken(request_token)
    self.email_settings_client.auth_token = access_token
    self.provisioning_client.auth_token = access_token

  def UpdateDomainUsersPopSettings(self):
    """Updates POP settings for all of the domain's users."""
    users = self.provisioning_client.RetrieveAllUsers()
    for user in users.entry:
      self.email_settings_client.UpdatePop(username=user.login.user_name,
                                           enable=True,
                                           enable_for='ALL_MAIL',
                                           action='ARCHIVE')


def PrintUsageString():
  """Prints the correct call for running the sample."""
  print ('python emailsettings_pop_settings.py'
         '--consumer_key [ConsumerKey] --consumer_secret [ConsumerSecret]'
         '--domain [domain]')


def main():
  """Updates POP settings for all of the domain's users
     using the Email Settings API.
  """
  try:
    opts, args = getopt.getopt(sys.argv[1:], '', ['consumer_key=',
                                                  'consumer_secret=',
                                                  'domain='])
  except getopt.error, msg:
    PrintUsageString()
    sys.exit(1)

  consumer_key = ''
  consumer_secret = ''
  domain = ''
  for option, arg in opts:
    if option == '--consumer_key':
      consumer_key = arg
    elif option == '--consumer_secret':
      consumer_secret = arg
    elif option == '--domain':
      domain = arg

  if not (consumer_key and consumer_secret and domain):
    print 'Requires exactly three flags.'
    PrintUsageString()
    sys.exit(1)

  pop_settings = PopSettings(
      consumer_key, consumer_secret, domain)
  try:
    pop_settings.Authorize()
    pop_settings.UpdateDomainUsersPopSettings()
  except gdata.client.RequestError, e:
    if e.status == 403:
      raise PopSettingsException('Invalid Domain')
    elif e.status == 400:
      raise PopSettingsException('Invalid consumer credentials')
    elif e.status == 503:
      raise PopSettingsException('Server busy')
    else e.status == 500:
      raise PopSettingsException('Internal server error')
    else:
      raise PopSettingsException('Unknown error')


if __name__ == '__main__':
  main()



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Live client tests for the Organization Unit Provisioning API."""

# This module is used for version 2 of the Google Data APIs.
# These tests attempt to connect to Google servers.


__author__ = 'Gunjan Sharma <gunjansharma@google.com>'


import random
import unittest
import gdata.apps.organization.client
import gdata.apps.organization.data
import gdata.client
import gdata.data
import gdata.gauth
import gdata.test_config as conf

conf.options.register_option(conf.APPS_DOMAIN_OPTION)


class OrganizationUnitProvisioningClientTest(unittest.TestCase):

  def setUp(self):
    self.client = gdata.apps.organization.client.OrganizationUnitProvisioningClient(
        domain='example.com')
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.apps.organization.client.OrganizationUnitProvisioningClient(
          domain=conf.options.get_value('appsdomain'))
      if conf.options.get_value('ssl') == 'true':
        self.client.ssl = True
      conf.configure_client(self.client,
                            'OrganizationUnitProvisioningClientTest',
                            self.client.auth_service, True)

  def tearDown(self):
    conf.close_client(self.client)

  def testClientConfiguration(self):
    self.assertEqual('apps-apis.google.com', self.client.host)
    self.assertEqual('2.0', self.client.api_version)
    self.assertEqual('apps', self.client.auth_service)
    self.assertEqual(
        ('https://apps-apis.google.com/a/feeds/user/',
         'https://apps-apis.google.com/a/feeds/policies/',
         'https://apps-apis.google.com/a/feeds/alias/',
         'https://apps-apis.google.com/a/feeds/groups/'),
        self.client.auth_scopes)
    if conf.options.get_value('runlive') == 'true':
      self.assertEqual(self.client.domain,
                       conf.options.get_value('appsdomain'))
    else:
      self.assertEqual(self.client.domain, 'example.com')

  def testMakeCustomerIdFeedUri(self):
    self.assertEqual('/a/feeds/customer/2.0/customerId',
                     self.client.MakeCustomerIdFeedUri())

  def testMakeOrganizationUnitOrgunitProvisioningUri(self):
    self.customer_id = 'tempo'
    self.assertEqual('/a/feeds/orgunit/2.0/%s' % self.customer_id,
                     self.client.MakeOrganizationUnitOrgunitProvisioningUri(
                         self.customer_id))
    self.assertEqual(
        '/a/feeds/orgunit/2.0/%s/testing/Test+Test' % self.customer_id,
        self.client.MakeOrganizationUnitOrgunitProvisioningUri(
            self.customer_id, org_unit_path='testing/Test+Test'))
    self.assertEqual(
        '/a/feeds/orgunit/2.0/%s?get=all' % (self.customer_id),
        self.client.MakeOrganizationUnitOrgunitProvisioningUri(
            self.customer_id, params={'get': 'all'}))

  def testMakeOrganizationUnitOrguserProvisioningUri(self):
    self.customer_id = 'tempo'
    self.assertEqual('/a/feeds/orguser/2.0/%s' % self.customer_id,
                     self.client.MakeOrganizationUnitOrguserProvisioningUri(
                         self.customer_id))
    self.assertEqual(
        '/a/feeds/orguser/2.0/%s/admin@example.com' % self.customer_id,
        self.client.MakeOrganizationUnitOrguserProvisioningUri(
            self.customer_id, org_user_email='admin@example.com'))
    self.assertEqual(
        '/a/feeds/orguser/2.0/%s?get=all' % (self.customer_id),
        self.client.MakeOrganizationUnitOrguserProvisioningUri(
            self.customer_id, params={'get': 'all'}))

  def testCreateRetrieveUpdateDelete(self):
    if not conf.options.get_value('runlive') == 'true':
      return

    # Either load the recording or prepare to make a live request.
    conf.configure_cache(self.client, 'testCreateRetrieveUpdateDelete')

    customer_id = self.client.RetrieveCustomerId().GetCustomerId()
    rnd_number = random.randrange(0, 100001)
    org_unit_name = 'test_org_unit_name%s' % (rnd_number)
    org_unit_description = 'test_org_unit_description%s' % (rnd_number)
    org_unit_path = org_unit_name

    new_entry = self.client.CreateOrgUnit(customer_id, org_unit_name,
                                          parent_org_unit_path='/',
                                          description=org_unit_description,
                                          block_inheritance=False)
    self.assert_(isinstance(new_entry,
                            gdata.apps.organization.data.OrgUnitEntry))
    self.assertEquals(new_entry.org_unit_path, org_unit_path)

    entry = self.client.RetrieveOrgUnit(customer_id, org_unit_path)
    self.assert_(isinstance(entry,
                            gdata.apps.organization.data.OrgUnitEntry))
    self.assertEquals(entry.org_unit_name, org_unit_name)
    self.assertEquals(entry.org_unit_description, org_unit_description)
    self.assertEquals(entry.parent_org_unit_path, '')
    self.assertEquals(entry.org_unit_path, org_unit_path)
    self.assertEquals(entry.org_unit_block_inheritance, 'false')

    self.client.DeleteOrgUnit(customer_id, org_unit_name)


def suite():
  return conf.build_suite([OrganizationUnitProvisioningClientTest])


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/env python
#
#    Copyright (C) 2009 Google Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# This module is used for version 2 of the Google Data APIs.


__author__ = 'j.s@google.com (Jeff Scudder)'


import unittest
import atom.auth
import atom.http_core


class BasicAuthTest(unittest.TestCase):
 
  def test_modify_request(self):
    http_request = atom.http_core.HttpRequest()
    credentials = atom.auth.BasicAuth('Aladdin', 'open sesame')
    self.assert_(credentials.basic_cookie == 'QWxhZGRpbjpvcGVuIHNlc2FtZQ==')
    credentials.modify_request(http_request)
    self.assert_(http_request.headers[
        'Authorization'] == 'Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==')


def suite():
  return unittest.TestSuite((unittest.makeSuite(BasicAuthTest,'test'),))


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Sample for the Provisioning API and the Email Settings API with OAuth 2.0."""

__author__ = 'Shraddha Gupta <shraddhag@google.com>'

from optparse import OptionParser
import gdata.apps
import gdata.apps.emailsettings.client
import gdata.apps.groups.client
import gdata.client
import gdata.gauth


API_VERSION = '2.0'
BASE_URL = '/a/feeds/group/%s' % API_VERSION
SCOPE = ('https://apps-apis.google.com/a/feeds/groups/ '
         'https://apps-apis.google.com/a/feeds/emailsettings/2.0/')
HOST = 'apps-apis.google.com'


class OAuth2ClientSample(object):
  """OAuth2ClientSample object demos the use of OAuth2Token for retrieving
  Members of a Group and updating Email Settings for them."""

  def __init__(self, domain, client_id, client_secret):
    """
    Args:
      domain: string Domain name (e.g. domain.com)
      client_id: string Client_id of domain admin account.
      client_secret: string Client_secret of domain admin account.
    """
    try:
      self.token = gdata.gauth.OAuth2Token(client_id=client_id,
                                           client_secret=client_secret,
                                           scope=SCOPE,
                                           user_agent='oauth2-provisioningv2')
      self.uri = self.token.generate_authorize_url()
      print 'Please visit this URL to authorize the application:'
      print self.uri
      # Get the verification code from the standard input.
      code = raw_input('What is the verification code? ').strip()
      self.token.get_access_token(code)
    except gdata.gauth.OAuth2AccessTokenError, e:
      print 'Invalid Access token, Check your credentials %s' % e
      exit(0)
    self.domain = domain
    self.baseuri = '%s/%s' % (BASE_URL, domain)
    self.client = gdata.apps.groups.client.GroupsProvisioningClient(
        domain=self.domain, auth_token=self.token)
    # Authorize the client. 
    # This will add the Authorization header to all future requests.
    self.token.authorize(self.client)
    self.email_client = gdata.apps.emailsettings.client.EmailSettingsClient(
        domain=self.domain, auth_token=self.token)
    self.token.authorize(self.email_client)

  def create_filter(self, feed):
    """Creates a mail filter that marks as read all messages not containing
    Domain name as one of their words for each member of the group.

    Args:
      feed: GroupMemberFeed members whose emailsettings need to updated
    """
    for entry in feed.entry:
      user_name, domain = entry.member_id.split('@', 1)
      if entry.member_type == 'User' and domain == self.domain:
        print 'creating filter for %s' % entry.member_id
        self.email_client.CreateFilter(user_name,
                                       does_not_have_the_word=self.domain,
                                       mark_as_read=True)
      elif entry.member_type == 'User':
        print 'User belongs to other Domain %s' %entry.member_id
      else:
        print 'Member is a group %s' %entry.member_id

  def run(self, group):
    feed = self.client.RetrieveAllMembers(group)
    self.create_filter(feed)


def main():
  """Demos the Provisioning API and the Email Settings API with OAuth 2.0."""
  usage = 'usage: %prog [options]'
  parser = OptionParser(usage=usage)
  parser.add_option('--DOMAIN',
                    help='Google Apps Domain, e.g. "domain.com".')
  parser.add_option('--CLIENT_ID',
                    help='Registered CLIENT_ID of Domain.')
  parser.add_option('--CLIENT_SECRET',
                    help='Registered CLIENT_SECRET of Domain.')
  parser.add_option('--GROUP',
                    help='Group identifier')
  (options, args) = parser.parse_args()

  if None in (options.DOMAIN, options.CLIENT_ID, options.CLIENT_SECRET,
      options.GROUP):
    parser.print_help()
    return

  sample = OAuth2ClientSample(options.DOMAIN,
      options.CLIENT_ID, options.CLIENT_SECRET)
  sample.run(options.GROUP)


if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright (C) 2007 SIOS Technology, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = 'tmatsuo@sios.com (Takashi Matsuo)'

import unittest
import time, os
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import re
import pickle

import atom
import atom.http
import atom.service
from atom import mock_http
import gdata.apps
import gdata.apps.service
import getpass

apps_domain = 'test.shehas.net'
apps_username = ''
apps_password = ''


def conceal_secrets(recordings):
  ret = []
  for rec in recordings:
    req, res = rec
    if req.data:
      req.data = re.sub(r'Passwd=[^&]+', 'Passwd=hogehoge', req.data)
    if res.body:
      res.body = re.sub(r'SID=[^\n]+', 'SID=hogehoge', res.body)
      res.body = re.sub(r'LSID=[^\n]+', 'LSID=hogehoge', res.body)
      res.body = re.sub(r'Auth=[^\n]+', 'Auth=hogehoge', res.body)
    if req.headers.has_key('Authorization'):
      req.headers['Authorization'] = 'hogehoge'
    ret.append((req, res))
  return ret

class AppsServiceBaseTest(object):

  def setUp(self):
    self.datafile = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                 "%s.pickle" % self.name)
    if os.path.isfile(self.datafile):
      f = open(self.datafile, "rb")
      data = pickle.load(f)
      f.close()
      http_client = mock_http.MockHttpClient(recordings=data)
    else:
      real_client = atom.http.ProxiedHttpClient()
      http_client = mock_http.MockHttpClient(real_client=real_client)

    email = apps_username + '@' + apps_domain
    self.apps_client = gdata.apps.service.AppsService(
      email=email, domain=apps_domain, password=apps_password,
      source='AppsClient "Unit" Tests')
    self.apps_client.http_client = http_client
    self.apps_client.ProgrammaticLogin()

  def tearDown(self):
    if self.apps_client.http_client.real_client:
      # create pickle file
      f = open(self.datafile, "wb")
      data = conceal_secrets(self.apps_client.http_client.recordings)
      pickle.dump(data, f)
      f.close()

class AppsServiceTestForGetGeneratorForAllRecipients(AppsServiceBaseTest,
                                                     unittest.TestCase):
  name = "AppsServiceTestForGetGeneratorForAllRecipients"
  def testGetGeneratorForAllRecipients(self):
    """Tests GetGeneratorForAllRecipientss method"""
    generator = self.apps_client.GetGeneratorForAllRecipients(
      "b101-20091013151051")
    i = 0
    for recipient_feed in generator:
      for a_recipient in recipient_feed.entry:
        i = i + 1
    self.assert_(i == 102)

class AppsServiceTestForGetGeneratorForAllEmailLists(AppsServiceBaseTest,
                                                     unittest.TestCase):
  name = "AppsServiceTestForGetGeneratorForAllEmailLists"
  def testGetGeneratorForAllEmailLists(self):
    """Tests GetGeneratorForAllEmailLists method"""
    generator = self.apps_client.GetGeneratorForAllEmailLists()
    i = 0
    for emaillist_feed in generator:
      for a_emaillist in emaillist_feed.entry:
        i = i + 1
    self.assert_(i == 105)

class AppsServiceTestForGetGeneratorForAllNicknames(AppsServiceBaseTest,
                                                unittest.TestCase):
  name = "AppsServiceTestForGetGeneratorForAllNicknames"
  def testGetGeneratorForAllNicknames(self):
    """Tests GetGeneratorForAllNicknames method"""
    generator = self.apps_client.GetGeneratorForAllNicknames()
    i = 0
    for nickname_feed in generator:
      for a_nickname in nickname_feed.entry:
        i = i + 1
    self.assert_(i == 102)


class AppsServiceTestForGetGeneratorForAllUsers(AppsServiceBaseTest,
                                                unittest.TestCase):
  name = "AppsServiceTestForGetGeneratorForAllUsers"
    
  def testGetGeneratorForAllUsers(self):
    """Tests GetGeneratorForAllUsers method"""
    generator = self.apps_client.GetGeneratorForAllUsers()
    i = 0
    for user_feed in generator:
      for a_user in user_feed.entry:
        i = i + 1
    self.assert_(i == 102)

if __name__ == '__main__':
  print ('The tests may delete or update your data.')
  apps_username = raw_input('Please enter your username: ')
  apps_password = getpass.getpass()
  unittest.main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import getpass

from gdata.contentforshopping.data import build_entry
from gdata.contentforshopping.client import ContentForShoppingClient

# Gather merchant information
account_id = raw_input('Merchant Account ID? ').strip()
email = raw_input('Google Email Address? ').strip()

# Create a client
client = ContentForShoppingClient(account_id)

# Perform programmatic login
client.client_login(email, getpass.getpass('Google Password? '),
    'Shopping API for Content sample', 'structuredcontent')

# Generate a product entry
product_entry = build_entry(
  product_id='ipod2',
  target_country = 'US',
  content_language = 'EN',
  title='iPod Nano 8GB',
  content='A nice small mp3 player',
  price='149',
  price_unit='USD',
  shipping_price = '5',
  shipping_price_unit = 'USD',
  tax_rate='17.5',
  condition = 'new',
  link = 'http://pseudoscience.co.uk/google4e823e35f032f011.html',
  identifier_exists='hello'
)

# Post it to the service
client.insert_product(product_entry)



#!/usr/bin/env python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# This module is used for version 2 of the Google Data APIs.


__author__ = 'j.s@google.com (Jeff Scudder)'


import unittest
import sys
import gdata.sample_util


class SettingsUtilTest(unittest.TestCase):

  def setUp(self):
    self.settings = gdata.sample_util.SettingsUtil()

  def test_get_param(self):
    self.assert_(self.settings.get_param('missing', ask=False) is None)
    self.settings.prefs['x'] = 'something'
    self.assertEqual(self.settings.get_param('x'), 'something')
  
  def test_get_param_from_command_line_arg(self):
    self.assert_('x' not in self.settings.prefs)
    self.assert_(self.settings.get_param('x', ask=False) is None)
    sys.argv.append('--x=something')
    self.assertEqual(self.settings.get_param('x'), 'something')
    self.assert_('x' not in self.settings.prefs)
    self.assert_('y' not in self.settings.prefs)
    self.assert_(self.settings.get_param('y', ask=False) is None)
    sys.argv.append('--y')
    sys.argv.append('other')
    self.assertEqual(self.settings.get_param('y', reuse=True), 'other')
    self.assertEqual(self.settings.prefs['y'], 'other')


def suite():
  return conf.build_suite([SettingsUtilTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
# -*-*- encoding: utf-8 -*-*-
#
# Copyright (C) 2006 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'j.s@google.com (Jeff Scudder)'


import sys
import unittest
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import atom
from gdata import test_data
import gdata.test_config as conf


class AuthorTest(unittest.TestCase):
  
  def setUp(self):
    self.author = atom.Author()
    
  def testEmptyAuthorShouldHaveEmptyExtensionsList(self):
    self.assert_(isinstance(self.author.extension_elements, list))
    self.assert_(len(self.author.extension_elements) == 0)
    
  def testNormalAuthorShouldHaveNoExtensionElements(self):
    self.author.name = atom.Name(text='Jeff Scudder')
    self.assert_(self.author.name.text == 'Jeff Scudder')
    self.assert_(len(self.author.extension_elements) == 0)
    new_author = atom.AuthorFromString(self.author.ToString())
    self.assert_(len(self.author.extension_elements) == 0)
    
    self.author.extension_elements.append(atom.ExtensionElement(
        'foo', text='bar'))
    self.assert_(len(self.author.extension_elements) == 1)
    self.assert_(self.author.name.text == 'Jeff Scudder')
    new_author = atom.AuthorFromString(self.author.ToString())
    self.assert_(len(self.author.extension_elements) == 1)
    self.assert_(new_author.name.text == 'Jeff Scudder')

  def testEmptyAuthorToAndFromStringShouldMatch(self):
    string_from_author = self.author.ToString()
    new_author = atom.AuthorFromString(string_from_author)
    string_from_new_author = new_author.ToString()
    self.assert_(string_from_author == string_from_new_author)
    
  def testAuthorWithNameToAndFromStringShouldMatch(self):
    self.author.name = atom.Name()
    self.author.name.text = 'Jeff Scudder'
    string_from_author = self.author.ToString()
    new_author = atom.AuthorFromString(string_from_author)
    string_from_new_author = new_author.ToString()
    self.assert_(string_from_author == string_from_new_author)
    self.assert_(self.author.name.text == new_author.name.text)
  
  def testExtensionElements(self):
    self.author.extension_attributes['foo1'] = 'bar'
    self.author.extension_attributes['foo2'] = 'rab'
    self.assert_(self.author.extension_attributes['foo1'] == 'bar')
    self.assert_(self.author.extension_attributes['foo2'] == 'rab')
    new_author = atom.AuthorFromString(self.author.ToString())
    self.assert_(new_author.extension_attributes['foo1'] == 'bar')
    self.assert_(new_author.extension_attributes['foo2'] == 'rab')
    
  def testConvertFullAuthorToAndFromString(self):
    author = atom.AuthorFromString(test_data.TEST_AUTHOR)
    self.assert_(author.name.text == 'John Doe')
    self.assert_(author.email.text == 'johndoes@someemailadress.com')
    self.assert_(author.uri.text == 'http://www.google.com')
    
    
class EmailTest(unittest.TestCase):
  
  def setUp(self):
    self.email = atom.Email()
    
  def testEmailToAndFromString(self):
    self.email.text = 'This is a test'
    new_email = atom.EmailFromString(self.email.ToString())
    self.assert_(self.email.text == new_email.text)
    self.assert_(self.email.extension_elements == 
        new_email.extension_elements)
    
  
class NameTest(unittest.TestCase):

  def setUp(self):
    self.name = atom.Name()
    
  def testEmptyNameToAndFromStringShouldMatch(self):
    string_from_name = self.name.ToString()
    new_name = atom.NameFromString(string_from_name)
    string_from_new_name = new_name.ToString()
    self.assert_(string_from_name == string_from_new_name)
    
  def testText(self):
    self.assert_(self.name.text is None)
    self.name.text = 'Jeff Scudder'
    self.assert_(self.name.text == 'Jeff Scudder')
    new_name = atom.NameFromString(self.name.ToString())
    self.assert_(new_name.text == self.name.text)
    
  def testExtensionElements(self):
    self.name.extension_attributes['foo'] = 'bar'
    self.assert_(self.name.extension_attributes['foo'] == 'bar')
    new_name = atom.NameFromString(self.name.ToString())
    self.assert_(new_name.extension_attributes['foo'] == 'bar')
    
    
class ExtensionElementTest(unittest.TestCase):
  
  def setUp(self):
    self.ee = atom.ExtensionElement('foo')
    
  def testEmptyEEShouldProduceEmptyString(self):
    pass
    
  def testEEParsesTreeCorrectly(self):
    deep_tree = atom.ExtensionElementFromString(test_data.EXTENSION_TREE)
    self.assert_(deep_tree.tag == 'feed')
    self.assert_(deep_tree.namespace == 'http://www.w3.org/2005/Atom')
    self.assert_(deep_tree.children[0].tag == 'author')
    self.assert_(deep_tree.children[0].namespace == 'http://www.google.com')
    self.assert_(deep_tree.children[0].children[0].tag == 'name')
    self.assert_(deep_tree.children[0].children[0].namespace == 
        'http://www.google.com')
    self.assert_(deep_tree.children[0].children[0].text.strip() == 'John Doe')
    self.assert_(deep_tree.children[0].children[0].children[0].text.strip() ==
        'Bar')
    foo = deep_tree.children[0].children[0].children[0]
    self.assert_(foo.tag == 'foo')
    self.assert_(foo.namespace == 'http://www.google.com')
    self.assert_(foo.attributes['up'] == 'down')
    self.assert_(foo.attributes['yes'] == 'no')
    self.assert_(foo.children == [])
  
  def testEEToAndFromStringShouldMatch(self):
    string_from_ee = self.ee.ToString()
    new_ee = atom.ExtensionElementFromString(string_from_ee)
    string_from_new_ee = new_ee.ToString()
    self.assert_(string_from_ee == string_from_new_ee)
    
    deep_tree = atom.ExtensionElementFromString(test_data.EXTENSION_TREE)    
    string_from_deep_tree = deep_tree.ToString()
    new_deep_tree = atom.ExtensionElementFromString(string_from_deep_tree)
    string_from_new_deep_tree = new_deep_tree.ToString()
    self.assert_(string_from_deep_tree == string_from_new_deep_tree)
    
    
class LinkTest(unittest.TestCase):
  
  def setUp(self):
    self.link = atom.Link()
    
  def testLinkToAndFromString(self):
    self.link.href = 'test href'
    self.link.hreflang = 'english'
    self.link.type = 'text/html'
    self.link.extension_attributes['foo'] = 'bar'
    self.assert_(self.link.href == 'test href')
    self.assert_(self.link.hreflang == 'english')
    self.assert_(self.link.type == 'text/html')
    self.assert_(self.link.extension_attributes['foo'] == 'bar')
    new_link = atom.LinkFromString(self.link.ToString())
    self.assert_(self.link.href == new_link.href)
    self.assert_(self.link.type == new_link.type)
    self.assert_(self.link.hreflang == new_link.hreflang)
    self.assert_(self.link.extension_attributes['foo'] == 
        new_link.extension_attributes['foo'])

  def testLinkType(self):
    test_link = atom.Link(link_type='text/html')
    self.assert_(test_link.type == 'text/html')


class GeneratorTest(unittest.TestCase):

  def setUp(self):
    self.generator = atom.Generator()

  def testGeneratorToAndFromString(self):
    self.generator.uri = 'www.google.com'
    self.generator.version = '1.0'
    self.generator.extension_attributes['foo'] = 'bar'
    self.assert_(self.generator.uri == 'www.google.com')
    self.assert_(self.generator.version == '1.0')
    self.assert_(self.generator.extension_attributes['foo'] == 'bar')
    new_generator = atom.GeneratorFromString(self.generator.ToString())
    self.assert_(self.generator.uri == new_generator.uri)
    self.assert_(self.generator.version == new_generator.version)
    self.assert_(self.generator.extension_attributes['foo'] ==
        new_generator.extension_attributes['foo'])


class TitleTest(unittest.TestCase):

  def setUp(self):
    self.title = atom.Title()

  def testTitleToAndFromString(self):
    self.title.type = 'text'
    self.title.text = 'Less: &lt;'
    self.assert_(self.title.type == 'text')
    self.assert_(self.title.text == 'Less: &lt;')
    new_title = atom.TitleFromString(self.title.ToString())
    self.assert_(self.title.type == new_title.type)
    self.assert_(self.title.text == new_title.text)


class SubtitleTest(unittest.TestCase):

  def setUp(self):
    self.subtitle = atom.Subtitle()

  def testTitleToAndFromString(self):
    self.subtitle.type = 'text'
    self.subtitle.text = 'sub & title'
    self.assert_(self.subtitle.type == 'text')
    self.assert_(self.subtitle.text == 'sub & title')
    new_subtitle = atom.SubtitleFromString(self.subtitle.ToString())
    self.assert_(self.subtitle.type == new_subtitle.type)
    self.assert_(self.subtitle.text == new_subtitle.text)


class SummaryTest(unittest.TestCase):

  def setUp(self):
    self.summary = atom.Summary()

  def testTitleToAndFromString(self):
    self.summary.type = 'text'
    self.summary.text = 'Less: &lt;'
    self.assert_(self.summary.type == 'text')
    self.assert_(self.summary.text == 'Less: &lt;')
    new_summary = atom.SummaryFromString(self.summary.ToString())
    self.assert_(self.summary.type == new_summary.type)
    self.assert_(self.summary.text == new_summary.text)


class CategoryTest(unittest.TestCase):

  def setUp(self):
    self.category = atom.Category()

  def testCategoryToAndFromString(self):
    self.category.term = 'x'
    self.category.scheme = 'y'
    self.category.label = 'z'
    self.assert_(self.category.term == 'x')
    self.assert_(self.category.scheme == 'y')
    self.assert_(self.category.label == 'z')
    new_category = atom.CategoryFromString(self.category.ToString())
    self.assert_(self.category.term == new_category.term)
    self.assert_(self.category.scheme == new_category.scheme)
    self.assert_(self.category.label == new_category.label)


class ContributorTest(unittest.TestCase):

  def setUp(self):
    self.contributor = atom.Contributor()

  def testContributorToAndFromString(self):
    self.contributor.name = atom.Name(text='J Scud')
    self.contributor.email = atom.Email(text='nobody@nowhere')
    self.contributor.uri = atom.Uri(text='http://www.google.com')
    self.assert_(self.contributor.name.text == 'J Scud')
    self.assert_(self.contributor.email.text == 'nobody@nowhere')
    self.assert_(self.contributor.uri.text == 'http://www.google.com')
    new_contributor = atom.ContributorFromString(self.contributor.ToString())
    self.assert_(self.contributor.name.text == new_contributor.name.text)
    self.assert_(self.contributor.email.text == new_contributor.email.text)
    self.assert_(self.contributor.uri.text == new_contributor.uri.text)


class IdTest(unittest.TestCase):

  def setUp(self):
    self.my_id = atom.Id()

  def testIdToAndFromString(self):
    self.my_id.text = 'my nifty id'
    self.assert_(self.my_id.text == 'my nifty id')
    new_id = atom.IdFromString(self.my_id.ToString())
    self.assert_(self.my_id.text == new_id.text)


class IconTest(unittest.TestCase):

  def setUp(self):
    self.icon = atom.Icon()

  def testIconToAndFromString(self):
    self.icon.text = 'my picture'
    self.assert_(self.icon.text == 'my picture')
    new_icon = atom.IconFromString(str(self.icon))
    self.assert_(self.icon.text == new_icon.text)


class LogoTest(unittest.TestCase):

  def setUp(self):
    self.logo = atom.Logo()

  def testLogoToAndFromString(self):
    self.logo.text = 'my logo'
    self.assert_(self.logo.text == 'my logo')
    new_logo = atom.LogoFromString(self.logo.ToString())
    self.assert_(self.logo.text == new_logo.text)


class RightsTest(unittest.TestCase):

  def setUp(self):
    self.rights = atom.Rights()

  def testContributorToAndFromString(self):
    self.rights.text = 'you have the right to remain silent'
    self.rights.type = 'text'
    self.assert_(self.rights.text == 'you have the right to remain silent')
    self.assert_(self.rights.type == 'text')
    new_rights = atom.RightsFromString(self.rights.ToString())
    self.assert_(self.rights.text == new_rights.text)
    self.assert_(self.rights.type == new_rights.type)


class UpdatedTest(unittest.TestCase):

  def setUp(self):
    self.updated = atom.Updated()

  def testUpdatedToAndFromString(self):
    self.updated.text = 'my time'
    self.assert_(self.updated.text == 'my time')
    new_updated = atom.UpdatedFromString(self.updated.ToString())
    self.assert_(self.updated.text == new_updated.text)


class PublishedTest(unittest.TestCase):

  def setUp(self):
    self.published = atom.Published()

  def testPublishedToAndFromString(self):
    self.published.text = 'pub time'
    self.assert_(self.published.text == 'pub time')
    new_published = atom.PublishedFromString(self.published.ToString())
    self.assert_(self.published.text == new_published.text)


class FeedEntryParentTest(unittest.TestCase):
  """The test accesses hidden methods in atom.FeedEntryParent"""

  def testConvertToAndFromElementTree(self):
    # Use entry because FeedEntryParent doesn't have a tag or namespace.
    original = atom.Entry()
    copy = atom.FeedEntryParent()
 
    original.author.append(atom.Author(name=atom.Name(text='J Scud')))
    self.assert_(original.author[0].name.text == 'J Scud')
    self.assert_(copy.author == [])

    original.id = atom.Id(text='test id')
    self.assert_(original.id.text == 'test id')
    self.assert_(copy.id is None)

    copy._HarvestElementTree(original._ToElementTree())
    self.assert_(original.author[0].name.text == copy.author[0].name.text)
    self.assert_(original.id.text == copy.id.text)


class EntryTest(unittest.TestCase):

  def testConvertToAndFromString(self):
    entry = atom.Entry()
    entry.author.append(atom.Author(name=atom.Name(text='js')))
    entry.title = atom.Title(text='my test entry')
    self.assert_(entry.author[0].name.text == 'js')
    self.assert_(entry.title.text == 'my test entry')
    new_entry = atom.EntryFromString(entry.ToString())
    self.assert_(new_entry.author[0].name.text == 'js')
    self.assert_(new_entry.title.text == 'my test entry')

  def testEntryCorrectlyConvertsActualData(self):
    entry = atom.EntryFromString(test_data.XML_ENTRY_1)
    self.assert_(entry.category[0].scheme == 
        'http://base.google.com/categories/itemtypes')
    self.assert_(entry.category[0].term == 'products')
    self.assert_(entry.id.text == '    http://www.google.com/test/id/url   ')
    self.assert_(entry.title.text == 'Testing 2000 series laptop')
    self.assert_(entry.title.type == 'text')
    self.assert_(entry.content.type == 'xhtml')
    #TODO check all other values for the test entry

  def testAppControl(self):
    entry = atom.EntryFromString(test_data.TEST_BASE_ENTRY)
    self.assertEquals(entry.control.draft.text, 'yes')
    self.assertEquals(len(entry.control.extension_elements), 1)
    self.assertEquals(entry.control.extension_elements[0].tag, 'disapproved')


class ControlTest(unittest.TestCase):

  def testConvertToAndFromString(self):
    control = atom.Control()
    control.text = 'some text'
    control.draft = atom.Draft(text='yes')
    self.assertEquals(control.draft.text, 'yes')
    self.assertEquals(control.text, 'some text')
    self.assertEquals(isinstance(control.draft, atom.Draft), True)
    new_control = atom.ControlFromString(str(control))
    self.assertEquals(control.draft.text, new_control.draft.text)
    self.assertEquals(control.text, new_control.text)
    self.assertEquals(isinstance(new_control.draft, atom.Draft), True)


class DraftTest(unittest.TestCase):

  def testConvertToAndFromString(self):
    draft = atom.Draft()
    draft.text = 'maybe'
    draft.extension_attributes['foo'] = 'bar'
    self.assertEquals(draft.text, 'maybe')
    self.assertEquals(draft.extension_attributes['foo'], 'bar')
    new_draft = atom.DraftFromString(str(draft))
    self.assertEquals(draft.text, new_draft.text)
    self.assertEquals(draft.extension_attributes['foo'], 
        new_draft.extension_attributes['foo'])
    
    
    
class SourceTest(unittest.TestCase):

  def testConvertToAndFromString(self):
    source = atom.Source()
    source.author.append(atom.Author(name=atom.Name(text='js')))
    source.title = atom.Title(text='my test source')
    source.generator = atom.Generator(text='gen')
    self.assert_(source.author[0].name.text == 'js')
    self.assert_(source.title.text == 'my test source')
    self.assert_(source.generator.text == 'gen')
    new_source = atom.SourceFromString(source.ToString())
    self.assert_(new_source.author[0].name.text == 'js')
    self.assert_(new_source.title.text == 'my test source')
    self.assert_(new_source.generator.text == 'gen')


class FeedTest(unittest.TestCase):

  def testConvertToAndFromString(self):
    feed = atom.Feed()
    feed.author.append(atom.Author(name=atom.Name(text='js')))
    feed.title = atom.Title(text='my test source')
    feed.generator = atom.Generator(text='gen')
    feed.entry.append(atom.Entry(author=[atom.Author(name=atom.Name(
        text='entry author'))]))
    self.assert_(feed.author[0].name.text == 'js')
    self.assert_(feed.title.text == 'my test source')
    self.assert_(feed.generator.text == 'gen')
    self.assert_(feed.entry[0].author[0].name.text == 'entry author')
    new_feed = atom.FeedFromString(feed.ToString())
    self.assert_(new_feed.author[0].name.text == 'js')
    self.assert_(new_feed.title.text == 'my test source')
    self.assert_(new_feed.generator.text == 'gen')    
    self.assert_(new_feed.entry[0].author[0].name.text == 'entry author')

  def testPreserveEntryOrder(self):
    test_xml = (
        '<feed xmlns="http://www.w3.org/2005/Atom">'
          '<entry><id>0</id></entry>'
          '<entry><id>1</id></entry>'
          '<title>Testing Order</title>'
          '<entry><id>2</id></entry>'
          '<entry><id>3</id></entry>'
          '<entry><id>4</id></entry>'
          '<entry><id>5</id></entry>'
          '<entry><id>6</id></entry>'
          '<entry><id>7</id></entry>'
          '<author/>'
          '<entry><id>8</id></entry>'
          '<id>feed_id</id>'
          '<entry><id>9</id></entry>'
        '</feed>')
    feed = atom.FeedFromString(test_xml)
    for i in xrange(10):
      self.assert_(feed.entry[i].id.text == str(i))
    feed = atom.FeedFromString(feed.ToString())
    for i in xrange(10):
      self.assert_(feed.entry[i].id.text == str(i))
    temp = feed.entry[3]
    feed.entry[3] = feed.entry[4]
    feed.entry[4] = temp
    self.assert_(feed.entry[2].id.text == '2')
    self.assert_(feed.entry[3].id.text == '4')
    self.assert_(feed.entry[4].id.text == '3')
    self.assert_(feed.entry[5].id.text == '5')
    feed = atom.FeedFromString(feed.ToString())
    self.assert_(feed.entry[2].id.text == '2')
    self.assert_(feed.entry[3].id.text == '4')
    self.assert_(feed.entry[4].id.text == '3')
    self.assert_(feed.entry[5].id.text == '5')


class ContentEntryParentTest(unittest.TestCase):
  """The test accesses hidden methods in atom.FeedEntryParent"""

  def setUp(self):
    self.content = atom.Content()

  def testConvertToAndFromElementTree(self):
    self.content.text = 'my content'
    self.content.type = 'text'
    self.content.src = 'my source'
    self.assert_(self.content.text == 'my content')
    self.assert_(self.content.type == 'text')
    self.assert_(self.content.src == 'my source')
    new_content = atom.ContentFromString(self.content.ToString())
    self.assert_(self.content.text == new_content.text)
    self.assert_(self.content.type == new_content.type)
    self.assert_(self.content.src == new_content.src)

  def testContentConstructorSetsSrc(self):
    new_content = atom.Content(src='abcd')
    self.assertEquals(new_content.src, 'abcd')


class PreserveUnkownElementTest(unittest.TestCase):
  """Tests correct preservation of XML elements which are non Atom"""
  
  def setUp(self):
    self.feed = atom.FeedFromString(test_data.GBASE_ATTRIBUTE_FEED)

  def testCaptureOpenSearchElements(self):
    self.assertEquals(self.feed.FindExtensions('totalResults')[0].tag,
        'totalResults')
    self.assertEquals(self.feed.FindExtensions('totalResults')[0].namespace,
        'http://a9.com/-/spec/opensearchrss/1.0/')
    open_search_extensions = self.feed.FindExtensions(
        namespace='http://a9.com/-/spec/opensearchrss/1.0/')
    self.assertEquals(len(open_search_extensions), 3)
    for element in open_search_extensions:
      self.assertEquals(element.namespace, 
          'http://a9.com/-/spec/opensearchrss/1.0/')

  def testCaptureMetaElements(self):
    meta_elements = self.feed.entry[0].FindExtensions(
        namespace='http://base.google.com/ns-metadata/1.0')
    self.assertEquals(len(meta_elements), 1)
    self.assertEquals(meta_elements[0].attributes['count'], '4416629')
    self.assertEquals(len(meta_elements[0].children), 10)

  def testCaptureMetaChildElements(self):
    meta_elements = self.feed.entry[0].FindExtensions(
        namespace='http://base.google.com/ns-metadata/1.0')
    meta_children = meta_elements[0].FindChildren(
        namespace='http://base.google.com/ns-metadata/1.0')
    self.assertEquals(len(meta_children), 10)
    for child in meta_children:
      self.assertEquals(child.tag, 'value')


class LinkFinderTest(unittest.TestCase):
  
  def setUp(self):
    self.entry = atom.EntryFromString(test_data.XML_ENTRY_1)

  def testLinkFinderGetsLicenseLink(self):
    self.assertEquals(isinstance(self.entry.GetLicenseLink(), atom.Link), 
                      True)
    self.assertEquals(self.entry.GetLicenseLink().href,
        'http://creativecommons.org/licenses/by-nc/2.5/rdf')
    self.assertEquals(self.entry.GetLicenseLink().rel, 'license')

  def testLinkFinderGetsAlternateLink(self):
    self.assertEquals(isinstance(self.entry.GetAlternateLink(), atom.Link), 
                      True)
    self.assertEquals(self.entry.GetAlternateLink().href,
        'http://www.provider-host.com/123456789')
    self.assertEquals(self.entry.GetAlternateLink().rel, 'alternate')


class AtomBaseTest(unittest.TestCase):

   def testAtomBaseConvertsExtensions(self):
     # Using Id because it adds no additional members.
     atom_base = atom.Id()
     extension_child = atom.ExtensionElement('foo', namespace='http://ns0.com')
     extension_grandchild = atom.ExtensionElement('bar', 
         namespace='http://ns0.com')
     extension_child.children.append(extension_grandchild)
     atom_base.extension_elements.append(extension_child)
     self.assertEquals(len(atom_base.extension_elements), 1)
     self.assertEquals(len(atom_base.extension_elements[0].children), 1)
     self.assertEquals(atom_base.extension_elements[0].tag, 'foo')
     self.assertEquals(atom_base.extension_elements[0].children[0].tag, 'bar')
     
     element_tree = atom_base._ToElementTree()
     self.assert_(element_tree.find('{http://ns0.com}foo') is not None)
     self.assert_(element_tree.find('{http://ns0.com}foo').find(
         '{http://ns0.com}bar') is not None)


class UtfParsingTest(unittest.TestCase):
  
  def setUp(self):
    self.test_xml = u"""<?xml version="1.0" encoding="utf-8"?>
<entry xmlns='http://www.w3.org/2005/Atom'>
  <id>http://www.google.com/test/id/url</id>
  <title type='\u03B1\u03BB\u03C6\u03B1'>\u03B1\u03BB\u03C6\u03B1</title>
</entry>"""

  def testMemberStringEncoding(self):
    atom_entry = atom.EntryFromString(self.test_xml)
    #self.assertEqual(atom_entry.title.type.encode('utf-8'), 
    #    u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8'))
    #self.assertEqual(atom_entry.title.text.encode('utf-8'), 
    #    u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8'))

    # Setting object members to unicode strings is supported even if 
    # MEMBER_STRING_ENCODING is set 'utf-8' (should it be?)
    atom_entry.title.type = u'\u03B1\u03BB\u03C6\u03B1'
    xml = atom_entry.ToString()
    self.assert_(u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8') in xml)

    # Make sure that we can use plain text when MEMBER_STRING_ENCODING is utf8
    atom_entry.title.type = "plain text"
    atom_entry.title.text = "more text"
    xml = atom_entry.ToString()
    self.assert_("plain text" in xml)
    self.assert_("more text" in xml)

    # Test something else than utf-8
    atom.MEMBER_STRING_ENCODING = 'iso8859_7'
    atom_entry = atom.EntryFromString(self.test_xml)
    self.assert_(atom_entry.title.type == u'\u03B1\u03BB\u03C6\u03B1'.encode(
        'iso8859_7'))
    self.assert_(atom_entry.title.text == u'\u03B1\u03BB\u03C6\u03B1'.encode(
        'iso8859_7'))

    # Test using unicode strings directly for object members
    atom.MEMBER_STRING_ENCODING = unicode
    atom_entry = atom.EntryFromString(self.test_xml)
    self.assert_(atom_entry.title.type == u'\u03B1\u03BB\u03C6\u03B1')
    self.assert_(atom_entry.title.text == u'\u03B1\u03BB\u03C6\u03B1')
    
    # Make sure that we can use plain text when MEMBER_STRING_ENCODING is 
    # unicode
    atom_entry.title.type = "plain text"
    atom_entry.title.text = "more text"
    xml = atom_entry.ToString()
    self.assert_("plain text" in xml)
    self.assert_("more text" in xml)

  def testConvertExampleXML(self):
    try:
      entry = atom.CreateClassFromXMLString(atom.Entry, 
          test_data.GBASE_STRING_ENCODING_ENTRY)
    except UnicodeDecodeError:
      self.fail('Error when converting XML')


class DeprecationDecoratorTest(unittest.TestCase):

  def testDeprecationWarning(self):
    def to_deprecate():
      return 5
    self.assertEqual(to_deprecate.func_name, 'to_deprecate')
    deprecated = atom.deprecated('test')(to_deprecate)
    self.assertNotEqual(to_deprecate, deprecated)
    # After decorating a function as deprecated, the function name should
    # still be the name of the original function.
    self.assertEqual(deprecated.func_name, 'to_deprecate')
    #@atom.deprecated()
    def also_deprecated():
      return 6
    also_deprecated = atom.deprecated()(also_deprecated)
    self.assertEqual(also_deprecated.func_name, 'also_deprecated')


def suite():
  return conf.build_suite([AuthorTest, EmailTest, NameTest, 
      ExtensionElementTest, LinkTest, GeneratorTest, TitleTest, SubtitleTest,
      SummaryTest, IdTest, IconTest, LogoTest, RightsTest, UpdatedTest,
      PublishedTest, FeedEntryParentTest, EntryTest, ContentEntryParentTest,
      PreserveUnkownElementTest, FeedTest, LinkFinderTest, AtomBaseTest, 
      UtfParsingTest, DeprecationDecoratorTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/env python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# This module is used for version 2 of the Google Data APIs.
# These tests attempt to connect to Google servers.


__author__ = 'j.s@google.com (Jeff Scudder)'


import os
import unittest
import gdata.client
import atom.http_core
import atom.mock_http_core
import atom.core
import gdata.data
import gdata.core
# TODO: switch to using v2 atom data once it is available.
import atom
import gdata.test_config as conf


conf.options.register_option(conf.BLOG_ID_OPTION)


class BloggerTest(unittest.TestCase):

  def setUp(self):
    self.client = None
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.client.GDClient()
      conf.configure_client(self.client, 'BloggerTest', 'blogger')

  def tearDown(self):
    conf.close_client(self.client)

  def test_create_update_delete(self):
    if not conf.options.get_value('runlive') == 'true':
      return
    # Either load the recording or prepare to make a live request.
    conf.configure_cache(self.client, 'test_create_update_delete')

    blog_post = atom.Entry(
        title=atom.Title(text='test from python BloggerTest'),
        content=atom.Content(text='This is only a test.'))
    http_request = atom.http_core.HttpRequest()
    http_request.add_body_part(str(blog_post), 'application/atom+xml')

    def entry_from_string_wrapper(response):
      self.assert_(response.getheader('content-type') is not None)
      self.assert_(response.getheader('gdata-version') is not None)
      return atom.EntryFromString(response.read())

    entry = self.client.request('POST', 
        'http://www.blogger.com/feeds/%s/posts/default' % (
            conf.options.get_value('blogid')),
         converter=entry_from_string_wrapper, http_request=http_request)
    self.assertEqual(entry.title.text, 'test from python BloggerTest')
    self.assertEqual(entry.content.text, 'This is only a test.')

    # Edit the test entry.
    edit_link = None
    for link in entry.link:
      # Find the edit link for this entry. 
      if link.rel == 'edit':
        edit_link = link.href
    entry.title.text = 'Edited'
    http_request = atom.http_core.HttpRequest()
    http_request.add_body_part(str(entry), 'application/atom+xml')
    edited_entry = self.client.request('PUT', edit_link,
         converter=entry_from_string_wrapper, http_request=http_request)
    self.assertEqual(edited_entry.title.text, 'Edited')
    self.assertEqual(edited_entry.content.text, entry.content.text)

    # Delete the test entry from the blog.
    edit_link = None
    for link in edited_entry.link:
      if link.rel == 'edit':
        edit_link = link.href
    response = self.client.request('DELETE', edit_link)
    self.assertEqual(response.status, 200)

  def test_use_version_two(self):
    if not conf.options.get_value('runlive') == 'true':
      return
    conf.configure_cache(self.client, 'test_use_version_two')

    # Use version 2 of the Blogger API. 
    self.client.api_version = '2'

    # Create a v2 blog post entry to post on the blog.
    entry = create_element('entry')
    entry._other_elements.append(
        create_element('title', text='Marriage!', 
            attributes={'type': 'text'}))
    entry._other_elements.append(
        create_element('content', attributes={'type': 'text'},
            text='Mr. Darcy has proposed marriage to me!'))
    entry._other_elements.append(
        create_element('category', 
            attributes={'scheme': TAG, 'term': 'marriage'})) 
    entry._other_elements.append(
        create_element('category', 
            attributes={'scheme': TAG, 'term': 'Mr. Darcy'}))

    http_request = atom.http_core.HttpRequest()
    http_request.add_body_part(entry.to_string(), 'application/atom+xml')
    posted = self.client.request('POST', 
        'http://www.blogger.com/feeds/%s/posts/default' % (
            conf.options.get_value('blogid')),
         converter=element_from_string, http_request=http_request)
    # Verify that the blog post content is correct.
    self.assertEqual(posted.get_elements('title', ATOM)[0].text, 'Marriage!')
    # TODO: uncomment once server bug is fixed.
    #self.assertEqual(posted.get_elements('content', ATOM)[0].text,
    #    'Mr. Darcy has proposed marriage to me!')
    found_tags = [False, False]
    categories = posted.get_elements('category', ATOM)
    self.assertEqual(len(categories), 2)
    for category in categories:
      if category.get_attributes('term')[0].value == 'marriage':
        found_tags[0] = True
      elif category.get_attributes('term')[0].value == 'Mr. Darcy':
        found_tags[1] = True
    self.assert_(found_tags[0])
    self.assert_(found_tags[1])

    # Find the blog post on the blog.
    self_link = None
    edit_link = None
    for link in posted.get_elements('link', ATOM):
      if link.get_attributes('rel')[0].value == 'self':
        self_link = link.get_attributes('href')[0].value
      elif link.get_attributes('rel')[0].value == 'edit':
        edit_link = link.get_attributes('href')[0].value
    self.assert_(self_link is not None)
    self.assert_(edit_link is not None)

    queried = self.client.request('GET', self_link, 
        converter=element_from_string)
    # TODO: add additional asserts to check content and etags.

    # Test queries using ETags.
    entry = self.client.get_entry(self_link)
    self.assert_(entry.etag is not None)
    self.assertRaises(gdata.client.NotModified, self.client.get_entry,
                      self_link, etag=entry.etag)

    # Delete the test blog post.
    self.client.request('DELETE', edit_link)


class ContactsTest(unittest.TestCase):

  def setUp(self):
    self.client = None
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.client.GDClient()
      conf.configure_client(self.client, 'ContactsTest', 'cp')

  def tearDown(self):
    conf.close_client(self.client)
  
  # Run this test and profiles fails
  def test_crud_version_two(self):
    if not conf.options.get_value('runlive') == 'true':
      return

    conf.configure_cache(self.client, 'test_crud_version_two')

    self.client.api_version = '2'

    entry = create_element('entry')
    entry._other_elements.append(
        create_element('title', ATOM, 'Jeff', {'type': 'text'}))
    entry._other_elements.append(
        create_element('email', GD, 
            attributes={'address': 'j.s@google.com', 'rel': WORK_REL}))

    http_request = atom.http_core.HttpRequest()
    http_request.add_body_part(entry.to_string(), 'application/atom+xml')
    posted = self.client.request('POST', 
        'http://www.google.com/m8/feeds/contacts/default/full',
        converter=element_from_string, http_request=http_request)

    self_link = None
    edit_link = None
    for link in posted.get_elements('link', ATOM):
      if link.get_attributes('rel')[0].value == 'self':
        self_link = link.get_attributes('href')[0].value
      elif link.get_attributes('rel')[0].value == 'edit':
        edit_link = link.get_attributes('href')[0].value
    self.assert_(self_link is not None)
    self.assert_(edit_link is not None)

    etag = posted.get_attributes('etag')[0].value
    self.assert_(etag is not None)
    self.assert_(len(etag) > 0)

    # Delete the test contact.
    http_request = atom.http_core.HttpRequest()
    http_request.headers['If-Match'] = etag
    self.client.request('DELETE', edit_link, http_request=http_request)


class VersionTwoClientContactsTest(unittest.TestCase):

  def setUp(self):
    self.client = None
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.client.GDClient()
      self.client.api_version = '2'
      conf.configure_client(self.client, 'VersionTwoClientContactsTest', 'cp')
    self.old_proxy = os.environ.get('https_proxy')

  def tearDown(self):
    if self.old_proxy:
      os.environ['https_proxy'] = self.old_proxy
    elif 'https_proxy' in os.environ:
      del os.environ['https_proxy']
    conf.close_client(self.client)

  def test_version_two_client(self):
    if not conf.options.get_value('runlive') == 'true':
      return
    conf.configure_cache(self.client, 'test_version_two_client')

    entry = gdata.data.GDEntry()
    entry._other_elements.append(
        create_element('title', ATOM, 'Test', {'type': 'text'}))
    entry._other_elements.append(
        create_element('email', GD, 
            attributes={'address': 'test@example.com', 'rel': WORK_REL}))

    # Create the test contact.
    posted = self.client.post(entry,
        'https://www.google.com/m8/feeds/contacts/default/full')
    self.assert_(isinstance(posted, gdata.data.GDEntry))
    self.assertEqual(posted.get_elements('title')[0].text, 'Test')
    self.assertEqual(posted.get_elements('email')[0].get_attributes(
        'address')[0].value, 'test@example.com')

    posted.get_elements('title')[0].text = 'Doug'
    edited = self.client.update(posted)
    self.assert_(isinstance(edited, gdata.data.GDEntry))
    self.assertEqual(edited.get_elements('title')[0].text, 'Doug')
    self.assertEqual(edited.get_elements('email')[0].get_attributes(
        'address')[0].value, 'test@example.com')

    # Delete the test contact.
    self.client.delete(edited)

  def notest_crud_over_https_proxy(self):
    import urllib
    PROXY_ADDR = '98.192.125.23'
    try:
      response = urllib.urlopen('http://' + PROXY_ADDR)
    except IOError:
      return
    # Only bother running the test if the proxy is up
    if response.getcode() == 200:
      os.environ['https_proxy'] = PROXY_ADDR
      # Perform the CRUD test above, this time over a proxy.
      self.test_version_two_client()

class JsoncRequestTest(unittest.TestCase):

  def setUp(self):
    self.client = gdata.client.GDClient()

  def test_get_jsonc(self):
    jsonc = self.client.get_feed(
        'http://gdata.youtube.com/feeds/api/videos?q=surfing&v=2&alt=jsonc',
        converter=gdata.core.parse_json_file)
    self.assertTrue(len(jsonc.data.items) > 0)


# Utility methods.
# The Atom XML namespace.
ATOM = 'http://www.w3.org/2005/Atom'
# URL used as the scheme for a blog post tag.
TAG = 'http://www.blogger.com/atom/ns#'
# Namespace for Google Data API elements.
GD = 'http://schemas.google.com/g/2005'
WORK_REL = 'http://schemas.google.com/g/2005#work'


def create_element(tag, namespace=ATOM, text=None, attributes=None):
  element = atom.core.XmlElement()
  element._qname = '{%s}%s' % (namespace, tag)
  if text is not None:
    element.text = text
  if attributes is not None:
    element._other_attributes = attributes.copy()
  return element


def element_from_string(response):
  return atom.core.xml_element_from_string(response.read(),
                                           atom.core.XmlElement)


def suite():
  return conf.build_suite([BloggerTest, ContactsTest, 
                           VersionTwoClientContactsTest,
                           JsoncRequestTest])


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/python
#
# Copyright (C) 2008 Yu-Jie Lin
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'livibetter (Yu-Jie Lin)'


import unittest
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import gdata
from gdata import test_data
import gdata.webmastertools as webmastertools


class IndexedTest(unittest.TestCase):

  def setUp(self):
    self.indexed = webmastertools.Indexed()

  def testToAndFromString(self):
    self.indexed.text = 'true'
    self.assert_(self.indexed.text == 'true')
    new_indexed = webmastertools.IndexedFromString(self.indexed.ToString())
    self.assert_(self.indexed.text == new_indexed.text)


class CrawledTest(unittest.TestCase):

  def setUp(self):
    self.crawled = webmastertools.Crawled()

  def testToAndFromString(self):
    self.crawled.text = 'true'
    self.assert_(self.crawled.text == 'true')
    new_crawled = webmastertools.CrawledFromString(self.crawled.ToString())
    self.assert_(self.crawled.text == new_crawled.text)


class GeoLocationTest(unittest.TestCase):

  def setUp(self):
    self.geolocation = webmastertools.GeoLocation()

  def testToAndFromString(self):
    self.geolocation.text = 'US'
    self.assert_(self.geolocation.text == 'US')
    new_geolocation = webmastertools.GeoLocationFromString(
        self.geolocation.ToString())
    self.assert_(self.geolocation.text == new_geolocation.text)


class PreferredDomainTest(unittest.TestCase):

  def setUp(self):
    self.preferred_domain = webmastertools.PreferredDomain()

  def testToAndFromString(self):
    self.preferred_domain.text = 'none'
    self.assert_(self.preferred_domain.text == 'none')
    new_preferred_domain = webmastertools.PreferredDomainFromString(
        self.preferred_domain.ToString())
    self.assert_(self.preferred_domain.text == new_preferred_domain.text)


class CrawlRateTest(unittest.TestCase):

  def setUp(self):
    self.crawl_rate = webmastertools.CrawlRate()

  def testToAndFromString(self):
    self.crawl_rate.text = 'normal'
    self.assert_(self.crawl_rate.text == 'normal')
    new_crawl_rate = webmastertools.CrawlRateFromString(
        self.crawl_rate.ToString())
    self.assert_(self.crawl_rate.text == new_crawl_rate.text)


class EnhancedImageSearchTest(unittest.TestCase):

  def setUp(self):
    self.enhanced_image_search = webmastertools.EnhancedImageSearch()

  def testToAndFromString(self):
    self.enhanced_image_search.text = 'true'
    self.assert_(self.enhanced_image_search.text == 'true')
    new_enhanced_image_search = webmastertools.EnhancedImageSearchFromString(
        self.enhanced_image_search.ToString())
    self.assert_(self.enhanced_image_search.text == 
        new_enhanced_image_search.text)


class VerifiedTest(unittest.TestCase):

  def setUp(self):
    self.verified = webmastertools.Verified()

  def testToAndFromString(self):
    self.verified.text = 'true'
    self.assert_(self.verified.text == 'true')
    new_verified = webmastertools.VerifiedFromString(self.verified.ToString())
    self.assert_(self.verified.text == new_verified.text)


class VerificationMethodMetaTest(unittest.TestCase):

  def setUp(self):
    self.meta = webmastertools.VerificationMethodMeta()

  def testToAndFromString(self):
    self.meta.name = 'verify-vf1'
    self.meta.content = 'a2Ai'
    self.assert_(self.meta.name == 'verify-vf1')
    self.assert_(self.meta.content == 'a2Ai')
    new_meta = webmastertools.VerificationMethodMetaFromString(
        self.meta.ToString())
    self.assert_(self.meta.name == new_meta.name)
    self.assert_(self.meta.content == new_meta.content)


class VerificationMethodTest(unittest.TestCase):

  def setUp(self):
    pass

  def testMetaTagToAndFromString(self):
    self.method = webmastertools.VerificationMethod()
    self.method.type = 'metatag'
    self.method.in_use = 'false'
    self.assert_(self.method.type == 'metatag')
    self.assert_(self.method.in_use == 'false')
    self.method.meta = webmastertools.VerificationMethodMeta(name='verify-vf1',
        content='a2Ai')
    self.assert_(self.method.meta.name == 'verify-vf1')
    self.assert_(self.method.meta.content == 'a2Ai')
    new_method = webmastertools.VerificationMethodFromString(
        self.method.ToString())
    self.assert_(self.method.type == new_method.type)
    self.assert_(self.method.in_use == new_method.in_use)
    self.assert_(self.method.meta.name == new_method.meta.name)
    self.assert_(self.method.meta.content == new_method.meta.content)

    method = webmastertools.VerificationMethod(type='xyz')
    self.assertEqual(method.type, 'xyz')
    method = webmastertools.VerificationMethod()
    self.assert_(method.type is None)

  def testHtmlPageToAndFromString(self):
    self.method = webmastertools.VerificationMethod()
    self.method.type = 'htmlpage'
    self.method.in_use = 'false'
    self.method.text = '456456-google.html'
    self.assert_(self.method.type == 'htmlpage')
    self.assert_(self.method.in_use == 'false')
    self.assert_(self.method.text == '456456-google.html')
    self.assert_(self.method.meta is None)
    new_method = webmastertools.VerificationMethodFromString(
        self.method.ToString())
    self.assert_(self.method.type == new_method.type)
    self.assert_(self.method.in_use == new_method.in_use)
    self.assert_(self.method.text == new_method.text)
    self.assert_(self.method.meta is None)

  def testConvertActualData(self):
    feed = webmastertools.SitesFeedFromString(test_data.SITES_FEED)
    self.assert_(len(feed.entry[0].verification_method) == 2)
    check = 0
    for method in feed.entry[0].verification_method:
      self.assert_(isinstance(method, webmastertools.VerificationMethod))
      if method.type == 'metatag':
        self.assert_(method.in_use == 'false')
        self.assert_(method.text is None)
        self.assert_(method.meta.name == 'verify-v1')
        self.assert_(method.meta.content == 'a2Ai')
        check = check | 1
      elif method.type == 'htmlpage':
        self.assert_(method.in_use == 'false')
        self.assert_(method.text == '456456-google.html')
        check = check | 2
      else:
        self.fail('Wrong Verification Method: %s' % method.type)
    self.assert_(check == 2 ** 2 - 1,
        'Should only have two Verification Methods, metatag and htmlpage')


class MarkupLanguageTest(unittest.TestCase):

  def setUp(self):
    self.markup_language = webmastertools.MarkupLanguage()

  def testToAndFromString(self):
    self.markup_language.text = 'HTML'
    self.assert_(self.markup_language.text == 'HTML')
    new_markup_language = webmastertools.MarkupLanguageFromString(
        self.markup_language.ToString())
    self.assert_(self.markup_language.text == new_markup_language.text)


class SitemapMobileTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_mobile = webmastertools.SitemapMobile()

  def testToAndFromString(self):
    self.sitemap_mobile.markup_language.append(webmastertools.MarkupLanguage(
        text = 'HTML'))
    self.assert_(self.sitemap_mobile.text is None)
    self.assert_(self.sitemap_mobile.markup_language[0].text == 'HTML')
    new_sitemap_mobile = webmastertools.SitemapMobileFromString(
        self.sitemap_mobile.ToString())
    self.assert_(new_sitemap_mobile.text is None)
    self.assert_(self.sitemap_mobile.markup_language[0].text == 
        new_sitemap_mobile.markup_language[0].text)

  def testConvertActualData(self):
    feed = webmastertools.SitemapsFeedFromString(test_data.SITEMAPS_FEED)
    self.assert_(feed.sitemap_mobile.text.strip() == '')
    self.assert_(len(feed.sitemap_mobile.markup_language) == 2)
    check = 0
    for markup_language in feed.sitemap_mobile.markup_language:
      self.assert_(isinstance(markup_language, webmastertools.MarkupLanguage))
      if markup_language.text == "HTML":
        check = check | 1
      elif markup_language.text == "WAP":
        check = check | 2
      else:
        self.fail('Unexpected markup language: %s' % markup_language.text)
    self.assert_(check == 2 ** 2 - 1, "Something is wrong with markup language")


class SitemapMobileMarkupLanguageTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_mobile_markup_language =\
        webmastertools.SitemapMobileMarkupLanguage()

  def testToAndFromString(self):
    self.sitemap_mobile_markup_language.text = 'HTML'
    self.assert_(self.sitemap_mobile_markup_language.text == 'HTML')
    new_sitemap_mobile_markup_language =\
        webmastertools.SitemapMobileMarkupLanguageFromString(
            self.sitemap_mobile_markup_language.ToString())
    self.assert_(self.sitemap_mobile_markup_language.text ==\
        new_sitemap_mobile_markup_language.text)


class PublicationLabelTest(unittest.TestCase):

  def setUp(self):
    self.publication_label = webmastertools.PublicationLabel()

  def testToAndFromString(self):
    self.publication_label.text = 'Value1'
    self.assert_(self.publication_label.text == 'Value1')
    new_publication_label = webmastertools.PublicationLabelFromString(
        self.publication_label.ToString())
    self.assert_(self.publication_label.text == new_publication_label.text)


class SitemapNewsTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_news = webmastertools.SitemapNews()

  def testToAndFromString(self):
    self.sitemap_news.publication_label.append(webmastertools.PublicationLabel(
        text = 'Value1'))
    self.assert_(self.sitemap_news.text is None)
    self.assert_(self.sitemap_news.publication_label[0].text == 'Value1')
    new_sitemap_news = webmastertools.SitemapNewsFromString(
        self.sitemap_news.ToString())
    self.assert_(new_sitemap_news.text is None)
    self.assert_(self.sitemap_news.publication_label[0].text == 
        new_sitemap_news.publication_label[0].text)

  def testConvertActualData(self):
    feed = webmastertools.SitemapsFeedFromString(test_data.SITEMAPS_FEED)
    self.assert_(len(feed.sitemap_news.publication_label) == 3)
    check = 0
    for publication_label in feed.sitemap_news.publication_label:
      if publication_label.text == "Value1":
        check = check | 1
      elif publication_label.text == "Value2":
        check = check | 2
      elif publication_label.text == "Value3":
        check = check | 4
      else:
        self.fail('Unexpected publication label: %s' % markup_language.text)
    self.assert_(check == 2 ** 3 - 1,
        'Something is wrong with publication label')


class SitemapNewsPublicationLabelTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_news_publication_label =\
        webmastertools.SitemapNewsPublicationLabel()

  def testToAndFromString(self):
    self.sitemap_news_publication_label.text = 'LabelValue'
    self.assert_(self.sitemap_news_publication_label.text == 'LabelValue')
    new_sitemap_news_publication_label =\
        webmastertools.SitemapNewsPublicationLabelFromString(
            self.sitemap_news_publication_label.ToString())
    self.assert_(self.sitemap_news_publication_label.text ==\
        new_sitemap_news_publication_label.text)


class SitemapLastDownloadedTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_last_downloaded = webmastertools.SitemapLastDownloaded()

  def testToAndFromString(self):
    self.sitemap_last_downloaded.text = '2006-11-18T19:27:32.543Z'
    self.assert_(self.sitemap_last_downloaded.text ==\
        '2006-11-18T19:27:32.543Z')
    new_sitemap_last_downloaded =\
        webmastertools.SitemapLastDownloadedFromString(
            self.sitemap_last_downloaded.ToString())
    self.assert_(self.sitemap_last_downloaded.text ==\
        new_sitemap_last_downloaded.text)


class SitemapTypeTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_type = webmastertools.SitemapType()

  def testToAndFromString(self):
    self.sitemap_type.text = 'WEB'
    self.assert_(self.sitemap_type.text == 'WEB')
    new_sitemap_type = webmastertools.SitemapTypeFromString(
        self.sitemap_type.ToString())
    self.assert_(self.sitemap_type.text == new_sitemap_type.text)


class SitemapStatusTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_status = webmastertools.SitemapStatus()

  def testToAndFromString(self):
    self.sitemap_status.text = 'Pending'
    self.assert_(self.sitemap_status.text == 'Pending')
    new_sitemap_status = webmastertools.SitemapStatusFromString(
        self.sitemap_status.ToString())
    self.assert_(self.sitemap_status.text == new_sitemap_status.text)


class SitemapUrlCountTest(unittest.TestCase):

  def setUp(self):
    self.sitemap_url_count = webmastertools.SitemapUrlCount()

  def testToAndFromString(self):
    self.sitemap_url_count.text = '0'
    self.assert_(self.sitemap_url_count.text == '0')
    new_sitemap_url_count = webmastertools.SitemapUrlCountFromString(
        self.sitemap_url_count.ToString())
    self.assert_(self.sitemap_url_count.text == new_sitemap_url_count.text)


class SitesEntryTest(unittest.TestCase):

  def setUp(self):
    pass
    
  def testToAndFromString(self):
    entry = webmastertools.SitesEntry(
        indexed=webmastertools.Indexed(text='true'),
        crawled=webmastertools.Crawled(text='2008-09-14T08:59:28.000'),
        geolocation=webmastertools.GeoLocation(text='US'),
        preferred_domain=webmastertools.PreferredDomain(text='none'),
        crawl_rate=webmastertools.CrawlRate(text='normal'),
        enhanced_image_search=webmastertools.EnhancedImageSearch(text='true'),
        verified=webmastertools.Verified(text='false'),
        )
    self.assert_(entry.indexed.text == 'true')
    self.assert_(entry.crawled.text == '2008-09-14T08:59:28.000')
    self.assert_(entry.geolocation.text == 'US')
    self.assert_(entry.preferred_domain.text == 'none')
    self.assert_(entry.crawl_rate.text == 'normal')
    self.assert_(entry.enhanced_image_search.text == 'true')
    self.assert_(entry.verified.text == 'false')
    new_entry = webmastertools.SitesEntryFromString(entry.ToString())
    self.assert_(new_entry.indexed.text == 'true')
    self.assert_(new_entry.crawled.text == '2008-09-14T08:59:28.000')
    self.assert_(new_entry.geolocation.text == 'US')
    self.assert_(new_entry.preferred_domain.text == 'none')
    self.assert_(new_entry.crawl_rate.text == 'normal')
    self.assert_(new_entry.enhanced_image_search.text == 'true')
    self.assert_(new_entry.verified.text == 'false')
    
  def testConvertActualData(self):
    feed = webmastertools.SitesFeedFromString(test_data.SITES_FEED)
    self.assert_(len(feed.entry) == 1)
    entry = feed.entry[0]
    self.assert_(isinstance(entry, webmastertools.SitesEntry))
    self.assert_(entry.indexed.text == 'true')
    self.assert_(entry.crawled.text == '2008-09-14T08:59:28.000')
    self.assert_(entry.geolocation.text == 'US')
    self.assert_(entry.preferred_domain.text == 'none')
    self.assert_(entry.crawl_rate.text == 'normal')
    self.assert_(entry.enhanced_image_search.text == 'true')
    self.assert_(entry.verified.text == 'false')


class SitesFeedTest(unittest.TestCase):
  
  def setUp(self):
    self.feed = gdata.webmastertools.SitesFeedFromString(test_data.SITES_FEED)
    
  def testToAndFromString(self):
    self.assert_(len(self.feed.entry) == 1)
    for entry in self.feed.entry:
      self.assert_(isinstance(entry, webmastertools.SitesEntry))
    new_feed = webmastertools.SitesFeedFromString(self.feed.ToString())
    self.assert_(len(new_feed.entry) == 1)
    for entry in new_feed.entry:
      self.assert_(isinstance(entry, webmastertools.SitesEntry))


class SitemapsEntryTest(unittest.TestCase):

  def testRegularToAndFromString(self):
    entry = webmastertools.SitemapsEntry(
       sitemap_type=webmastertools.SitemapType(text='WEB'),
       sitemap_status=webmastertools.SitemapStatus(text='Pending'),
       sitemap_last_downloaded=webmastertools.SitemapLastDownloaded(
          text='2006-11-18T19:27:32.543Z'),
       sitemap_url_count=webmastertools.SitemapUrlCount(text='102'),
       )
    self.assert_(entry.sitemap_type.text == 'WEB')
    self.assert_(entry.sitemap_status.text == 'Pending')
    self.assert_(entry.sitemap_last_downloaded.text ==\
        '2006-11-18T19:27:32.543Z')
    self.assert_(entry.sitemap_url_count.text == '102')
    new_entry = webmastertools.SitemapsEntryFromString(entry.ToString())
    self.assert_(new_entry.sitemap_type.text == 'WEB')
    self.assert_(new_entry.sitemap_status.text == 'Pending')
    self.assert_(new_entry.sitemap_last_downloaded.text ==\
        '2006-11-18T19:27:32.543Z')
    self.assert_(new_entry.sitemap_url_count.text == '102')

  def testConvertActualData(self):
    feed = gdata.webmastertools.SitemapsFeedFromString(test_data.SITEMAPS_FEED)
    self.assert_(len(feed.entry) == 3)
    for entry in feed.entry:
      self.assert_(entry, webmastertools.SitemapsEntry)
      self.assert_(entry.sitemap_status, webmastertools.SitemapStatus)
      self.assert_(entry.sitemap_last_downloaded,
          webmastertools.SitemapLastDownloaded)
      self.assert_(entry.sitemap_url_count, webmastertools.SitemapUrlCount)
      self.assert_(entry.sitemap_status.text == 'StatusValue')
      self.assert_(entry.sitemap_last_downloaded.text ==\
          '2006-11-18T19:27:32.543Z')
      self.assert_(entry.sitemap_url_count.text == '102')
      if entry.id.text == 'http://www.example.com/sitemap-index.xml':
        self.assert_(entry.sitemap_type, webmastertools.SitemapType)
        self.assert_(entry.sitemap_type.text == 'WEB')
        self.assert_(entry.sitemap_mobile_markup_language is None)
        self.assert_(entry.sitemap_news_publication_label is None)
      elif entry.id.text == 'http://www.example.com/mobile/sitemap-index.xml':
        self.assert_(entry.sitemap_mobile_markup_language,
            webmastertools.SitemapMobileMarkupLanguage)
        self.assert_(entry.sitemap_mobile_markup_language.text == 'HTML')
        self.assert_(entry.sitemap_type is None)
        self.assert_(entry.sitemap_news_publication_label is None)
      elif entry.id.text == 'http://www.example.com/news/sitemap-index.xml':
        self.assert_(entry.sitemap_news_publication_label,
            webmastertools.SitemapNewsPublicationLabel)
        self.assert_(entry.sitemap_news_publication_label.text == 'LabelValue')
        self.assert_(entry.sitemap_type is None)
        self.assert_(entry.sitemap_mobile_markup_language is None)


class SitemapsFeedTest(unittest.TestCase):
  
  def setUp(self):
    self.feed = gdata.webmastertools.SitemapsFeedFromString(
        test_data.SITEMAPS_FEED)
    
  def testToAndFromString(self):
    self.assert_(len(self.feed.entry) == 3)
    for entry in self.feed.entry:
      self.assert_(isinstance(entry, webmastertools.SitemapsEntry))
    new_feed = webmastertools.SitemapsFeedFromString(self.feed.ToString())
    self.assert_(len(new_feed.entry) == 3)
    for entry in new_feed.entry:
      self.assert_(isinstance(entry, webmastertools.SitemapsEntry))


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Contains a Sample for Google Apps Admin Settings.

  AdminSettingsSample: shows everything you ever wanted to know about
                       your Google Apps Domain but were afraid to ask.
"""

__author__ = 'jlee@pbu.edu'

import getopt
import getpass
import sys
import time

import gdata.apps.service
import gdata.apps.adminsettings.service

class AdminSettingsSample(object):
  """AdminSettingsSample object demos Admin Settings API."""

  def __init__(self, email, password, domain):
    """Constructor for the AdminSettingsSample object.

    Takes an email and password corresponding to a google apps admin
    account to demon the Admin Settings API.

    Args:
      email: [string] The e-mail address of the account to use for the sample.
      password: [string] The password corresponding to the account specified by
          the email parameter.
      domain: [string] The domain for the Profiles feed
    """
    self.gd_client = gdata.apps.adminsettings.service.AdminSettingsService()
    self.gd_client.domain = domain
    self.gd_client.email = email
    self.gd_client.password = password
    self.gd_client.source = 'GoogleInc-AdminSettingsPythonSample-1'
    self.gd_client.ProgrammaticLogin()

  def Run(self):
    #pause 1 sec inbetween calls to prevent quota warning
    print 'Google Apps Domain: ', self.gd_client.domain
    time.sleep(1)
    print 'Default Language: ', self.gd_client.GetDefaultLanguage()
    time.sleep(1)
    print 'Organization Name: ', self.gd_client.GetOrganizationName()
    time.sleep(1)
    print 'Maximum Users: ', self.gd_client.GetMaximumNumberOfUsers()
    time.sleep(1)
    print 'Current Users: ', self.gd_client.GetCurrentNumberOfUsers()
    time.sleep(1)
    print 'Domain is Verified: ',self.gd_client.IsDomainVerified()
    time.sleep(1)
    print 'Support PIN: ',self.gd_client.GetSupportPIN()
    time.sleep(1)
    print 'Domain Edition: ', self.gd_client.GetEdition()
    time.sleep(1)
    print 'Customer PIN: ', self.gd_client.GetCustomerPIN()
    time.sleep(1)
    print 'Domain Creation Time: ', self.gd_client.GetCreationTime()
    time.sleep(1)
    print 'Domain Country Code: ', self.gd_client.GetCountryCode()
    time.sleep(1)
    print 'Admin Secondary Email: ', self.gd_client.GetAdminSecondaryEmail()
    time.sleep(1)
    cnameverificationstatus = self.gd_client.GetCNAMEVerificationStatus()
    print 'CNAME Verification Record Name: ', cnameverificationstatus['recordName']
    print 'CNAME Verification Verified: ', cnameverificationstatus['verified']
    print 'CNAME Verification Method: ', cnameverificationstatus['verificationMethod']
    time.sleep(1)
    mxverificationstatus = self.gd_client.GetMXVerificationStatus()
    print 'MX Verification Verified: ', mxverificationstatus['verified']
    print 'MX Verification Method: ', mxverificationstatus['verificationMethod']
    time.sleep(1)
    ssosettings = self.gd_client.GetSSOSettings()
    print 'SSO Enabled: ', ssosettings['enableSSO']
    print 'SSO Signon Page: ', ssosettings['samlSignonUri']
    print 'SSO Logout Page: ', ssosettings['samlLogoutUri']
    print 'SSO Password Page: ', ssosettings['changePasswordUri']
    print 'SSO Whitelist IPs: ', ssosettings['ssoWhitelist']
    print 'SSO Use Domain Specific Issuer: ', ssosettings['useDomainSpecificIssuer']
    time.sleep(1)
    ssokey = self.gd_client.GetSSOKey()
    print 'SSO Key Modulus: ', ssokey['modulus']
    print 'SSO Key Exponent: ', ssokey['exponent']
    print 'SSO Key Algorithm: ', ssokey['algorithm']
    print 'SSO Key Format: ', ssokey['format']
    print 'User Migration Enabled: ', self.gd_client.IsUserMigrationEnabled()
    time.sleep(1)
    outboundgatewaysettings = self.gd_client.GetOutboundGatewaySettings()
    print 'Outbound Gateway Smart Host: ', outboundgatewaysettings['smartHost']
    print 'Outbound Gateway Mode: ', outboundgatewaysettings['smtpMode']

def main():
  """Demonstrates use of the Admin Settings API using the AdminSettingsSample object."""
  # Parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], '', ['user=', 'pw=', 'domain='])
  except getopt.error, msg:
    print 'python adminsettings_example.py --user [username] --pw [password]'
    print ' --domain [domain]'
    sys.exit(2)

  user = ''
  pw = ''
  domain = ''

  # Process options
  for option, arg in opts:
    if option == '--user':
      user = arg
    elif option == '--pw':
      pw = arg
    elif option == '--domain':
      domain = arg

  while not domain:
    print 'NOTE: Please run these tests only with a test account.'
    domain = raw_input('Please enter your apps domain: ')
  while not user:
    user = raw_input('Please enter a administrator account: ')+'@'+domain
  while not pw:
    pw = getpass.getpass('Please enter password: ')
    if not pw:
      print 'Password cannot be blank.'

  try:
    sample = AdminSettingsSample(user, pw, domain)
  except gdata.service.BadAuthentication:
    print 'Invalid user credentials given.'
    return

  sample.Run()

if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright (C) 2008 Google
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Test for Groups service."""


__author__ = 'google-apps-apis@googlegroups.com'


import unittest
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import atom
import gdata.apps
import gdata.apps.service
import gdata.apps.groups.service
import getpass
import time


domain = ''
admin_email = ''
admin_password = ''
username = ''


class GroupsTest(unittest.TestCase):
  """Test for the GroupsService."""

  def setUp(self):
    self.postfix = time.strftime("%Y%m%d%H%M%S")
    self.apps_client = gdata.apps.service.AppsService(
        email=admin_email, domain=domain, password=admin_password,
        source='GroupsClient "Unit" Tests')
    self.apps_client.ProgrammaticLogin()
    self.groups_client = gdata.apps.groups.service.GroupsService(
        email=admin_email, domain=domain, password=admin_password,
        source='GroupsClient "Unit" Tests')
    self.groups_client.ProgrammaticLogin()  
    self.created_users = []
    self.created_groups = []
    self.createUsers();

  def createUsers(self):
    user_name = 'yujimatsuo-' + self.postfix
    family_name = 'Matsuo'
    given_name = 'Yuji'
    password = '123$$abc'
    suspended = 'false'

    try:
      self.user_yuji = self.apps_client.CreateUser(
          user_name=user_name, family_name=family_name, given_name=given_name,
          password=password, suspended=suspended)
      print 'User ' + user_name + ' created'
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.created_users.append(self.user_yuji)

    user_name = 'taromatsuo-' + self.postfix
    family_name = 'Matsuo'
    given_name = 'Taro'
    password = '123$$abc'
    suspended = 'false'

    try:
      self.user_taro = self.apps_client.CreateUser(
          user_name=user_name, family_name=family_name, given_name=given_name,
          password=password, suspended=suspended)
      print 'User ' + user_name + ' created'
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.created_users.append(self.user_taro)

  def tearDown(self):
    print '\n'
    for user in self.created_users:
      try:
        self.apps_client.DeleteUser(user.login.user_name)
        print 'User ' + user.login.user_name + ' deleted'
      except Exception, e:
        print e
    for group in self.created_groups:
      try:
        self.groups_client.DeleteGroup(group)
        print 'Group ' + group + ' deleted'
      except Exception, e:
        print e

  def test001GroupsMethods(self):
    # tests CreateGroup method
    group01_id = 'group01-' + self.postfix
    group02_id = 'group02-' + self.postfix
    try:
      created_group01 = self.groups_client.CreateGroup(group01_id, 'US Sales 1',
          'Testing', gdata.apps.groups.service.PERMISSION_OWNER)
      created_group02 = self.groups_client.CreateGroup(group02_id, 'US Sales 2',
          'Testing', gdata.apps.groups.service.PERMISSION_OWNER)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.assertEquals(created_group01['groupId'], group01_id)
    self.assertEquals(created_group02['groupId'], group02_id)
    self.created_groups.append(group01_id)
    self.created_groups.append(group02_id)
   
    # tests UpdateGroup method
    try:
      updated_group = self.groups_client.UpdateGroup(group01_id, 'Updated!',
          'Testing', gdata.apps.groups.service.PERMISSION_OWNER)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.assertEquals(updated_group['groupName'], 'Updated!')

    # tests RetrieveGroup method
    try:
      retrieved_group = self.groups_client.RetrieveGroup(group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.assertEquals(retrieved_group['groupId'], group01_id + '@' + domain)
   
    # tests RetrieveAllGroups method
    try:
      retrieved_groups = self.groups_client.RetrieveAllGroups()
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.assertEquals(len(retrieved_groups),
                      len(self.apps_client.RetrieveAllEmailLists().entry))
   
    # tests AddMemberToGroup
    try:
      added_member = self.groups_client.AddMemberToGroup(
          self.user_yuji.login.user_name, group01_id)
      self.groups_client.AddMemberToGroup(
          self.user_taro.login.user_name, group02_id)
      self.groups_client.AddMemberToGroup(
          group01_id, group02_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(added_member['memberId'],
                      self.user_yuji.login.user_name)
   
    # tests RetrieveGroups method
    try:
      retrieved_direct_groups = self.groups_client.RetrieveGroups(
          self.user_yuji.login.user_name, True)
      retrieved_groups = self.groups_client.RetrieveGroups(
          self.user_yuji.login.user_name, False)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)

    self.assertEquals(len(retrieved_direct_groups), 1)
    # TODO: Enable this test after a directOnly bug is fixed
    #self.assertEquals(len(retrieved_groups), 2)

    # tests IsMember method
    try:
      result = self.groups_client.IsMember(
          self.user_yuji.login.user_name, group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(result, True)
   
    # tests RetrieveMember method
    try:
      retrieved_member = self.groups_client.RetrieveMember(
          self.user_yuji.login.user_name, group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(retrieved_member['memberId'],
                      self.user_yuji.login.user_name + '@' + domain)
   
    # tests RetrieveAllMembers method
    try:
      retrieved_members = self.groups_client.RetrieveAllMembers(group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(len(retrieved_members), 1)
   
    # tests RemoveMemberFromGroup method
    try:
      self.groups_client.RemoveMemberFromGroup(self.user_yuji.login.user_name,
                                               group01_id)
      retrieved_members = self.groups_client.RetrieveAllMembers(group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(len(retrieved_members), 0)
   
    # tests AddOwnerToGroup
    try:
      added_owner = self.groups_client.AddOwnerToGroup(
          self.user_yuji.login.user_name, group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(added_owner['email'],
                      self.user_yuji.login.user_name)

    # tests IsOwner method
    try:
      result = self.groups_client.IsOwner(
          self.user_yuji.login.user_name, group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(result, True)
   
    # tests RetrieveOwner method
    try:
      retrieved_owner = self.groups_client.RetrieveOwner(
          self.user_yuji.login.user_name, group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(retrieved_owner['email'],
                      self.user_yuji.login.user_name + '@' + domain)
   
    # tests RetrieveAllOwners method
    try:
      retrieved_owners = self.groups_client.RetrieveAllOwners(group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(len(retrieved_owners), 1)
   
    # tests RemoveOwnerFromGroup method
    try:
      self.groups_client.RemoveOwnerFromGroup(self.user_yuji.login.user_name,
                                               group01_id)
      retrieved_owners = self.groups_client.RetrieveAllOwners(group01_id)
    except Exception, e:
      self.fail('Unexpected exception occurred: %s' % e)
     
    self.assertEquals(len(retrieved_owners), 0)


if __name__ == '__main__':
  print("""Google Apps Groups Service Tests

NOTE: Please run these tests only with a test user account.
""")
  domain = raw_input('Google Apps domain: ')
  admin_email = '%s@%s' % (raw_input('Administrator username: '), domain)
  admin_password = getpass.getpass('Administrator password: ')
  unittest.main()



#!/usr/bin/env python
#
#    Copyright (C) 2009 Google Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# This module is used for version 2 of the Google Data APIs.


__author__ = 'j.s@google.com (Jeff Scudder)'


import unittest
import coverage
import all_tests
import atom.core
import atom.http_core
import atom.mock_http_core
import atom.auth
import atom.client
import gdata.gauth
import gdata.client
import gdata.data
import gdata.blogger.data
import gdata.blogger.client
import gdata.spreadsheets.data
from gdata.test_config import settings


# Ensure that coverage tests execute the live requests to the servers, but
# allow use of cached server responses to speed up repeated runs.
settings.RUN_LIVE_TESTS = True
settings.CLEAR_CACHE = False


def suite():
  return unittest.TestSuite((atom_tests.core_test.suite(),))

if __name__ == '__main__':
  coverage.erase()
  coverage.start()
  unittest.TextTestRunner().run(all_tests.suite())
  coverage.stop()
  coverage.report([atom.core, atom.http_core, atom.auth, atom.data,
      atom.mock_http_core, atom.client, gdata.gauth, gdata.client,
      gdata.core, gdata.data, gdata.blogger.data, gdata.blogger.client,
      gdata.spreadsheets.data])



#!/usr/bin/python

import sys
import unittest
import module_test_runner
import getopt
import getpass
# Modules whose tests we will run.
import gdata_test
import atom_test
import atom_tests.http_interface_test
import atom_tests.mock_http_test
import atom_tests.token_store_test
import atom_tests.url_test
import atom_tests.core_test
import gdata_tests.apps.emailsettings.data_test
import gdata_tests.apps.multidomain.data_test
import gdata_tests.apps_test
import gdata_tests.auth_test
import gdata_tests.books_test
import gdata_tests.blogger_test
import gdata_tests.calendar_test
import gdata_tests.calendar_resource.data_test
import gdata_tests.client_test
import gdata_tests.codesearch_test
import gdata_tests.contacts_test
import gdata_tests.docs_test
import gdata_tests.health_test
import gdata_tests.photos_test
import gdata_tests.spreadsheet_test
import gdata_tests.youtube_test
import gdata_tests.webmastertools_test
import gdata_tests.oauth.data_test


def RunAllTests():
  test_runner = module_test_runner.ModuleTestRunner()
  test_runner.modules = [gdata_test, atom_test, atom_tests.url_test, 
                         atom_tests.http_interface_test, 
                         atom_tests.mock_http_test, 
                         atom_tests.core_test,
                         atom_tests.token_store_test,
                         gdata_tests.client_test,
                         gdata_tests.apps_test,
                         gdata_tests.apps.emailsettings.data_test,
                         gdata_tests.apps.multidomain.data_test,
                         gdata_tests.auth_test, 
                         gdata_tests.books_test,
                         gdata_tests.calendar_test, gdata_tests.docs_test,
                         gdata_tests.health_test, gdata_tests.spreadsheet_test,
                         gdata_tests.photos_test, gdata_tests.codesearch_test,
                         gdata_tests.contacts_test,
                         gdata_tests.youtube_test, gdata_tests.blogger_test, 
                         gdata_tests.webmastertools_test,
                         gdata_tests.calendar_resource.data_test,
                         gdata_tests.oauth.data_test]
  test_runner.RunAllTests()
  
if __name__ == '__main__':
  RunAllTests()
